@charset "UTF-8";
/*
Theme Name: Dropout
Theme URI: http://zmthemes.com/dropout-wp
Author: gfxbucket
Author URI: http://themeforest.net/user/gfxbucket
Description: /
Version: 1.0
Template: dropout
Tags: /
Text Domain: dropout-child
*/
@import url('//fonts.googleapis.com/css?family=Open+Sans:400,700,300');

/*.columnsPaíses:nth-child(1){
   height: 40px !important;
}*/

#panel-392-0-2-0 {
  margin-top: 70px !important;
}


#pg-502-5 {

  margin-bottom: 0px !important;
}

.sow-image-container {

  display: block !important;
}

.botonContract {
  background: white;
  padding: .7em 1.3em;
  border-radius: .3em;
  border: 1px solid #b5aaaa;
  font-weight: 500;
  color: gray;
  display: block;
  max-width: 8em;
  text-align: center;
  margin: 0 auto;
  font-size: .9em;
}

#rev_slider_29_1_wrapper {

  max-height: 400px !important;
}

#menu-item-8470,
#menu-item-10324 {
  position: absolute;
  top: -1em;
  right: 7.75em;
  font-weight: 100;
  text-transform: none;
  color: #C7C3C3 !important;
}

#menu-item-10324 {
  right: 1.05em;
  top: -2.25em;
}

.ancla {
  position: relative;
  top: -6em;
  visibility: hidden;
}

.wpcf7-submit {
  margin-top: 0 !important;
}

@media (min-width: 768px) {

  .container,
  footer .container .container {
    width: 750px !important;
  }

  .color-row {
    background-color: #E5E5E5;
    width: 100%;
    padding: 0;
  }

  .nocolor-row {
    width: 100%;
    padding: 0;
  }

  #pg-6451-4 {
    margin-bottom: -58px !important;
  }

  #pg-6451-3 {
    padding-bottom: 60px !important;
  }

  #pgc-6394-1-0 h2 {
    margin-top: -15px !important;
    margin-bottom: 0 !important;
    font-weight: 500;

  }


  #menu-item-8470 a {
    color: #C7C3C3 !important;
    padding-bottom: 0;
    padding-top: 5px;
  }

  body.nav-scroll-active #menu-item-10324 a {
    padding-top: 22px;
  }

  .page-spacing .site {
    padding-top: 120px !important;
  }
}

@media (min-width: 992px) {

  .container,
  footer .container .container {
    width: 84% !important;
  }

  .color-row {
    background-color: #E5E5E5;
    width: 100%;
    padding: 0px 8% !important;
  }

  .nocolor-row {
    width: 100%;
    padding: 0px 8% !important;
  }

  .nav-sticky .site-header .nav-row {
    height: 100px;
    padding-top: 25px;
  }
}

@media (min-width: 1200px) {

  .container,
  footer .container .container {
    width: 84% !important;
  }

  .color-row {
    background-color: #E5E5E5;
    width: 100%;
    padding: 0px 18% !important;
  }

  .nocolor-row {
    width: 100%;
    padding: 0px 18% !important;
  }
}

.color-row .panel-grid-cell {
  padding-left: 25px !important;
  padding-right: 25px !important;
}

@media screen and (max-width: 767px) {
  .color-row .panel-grid-cell {
    padding-left: 0 !important;
    padding-right: 0 !important;
  }

}

.nav-desktop .site-header .nav-menu>ul>li+li {
  margin-left: 17px !important;
}

.nav-desktop .site-header .nav-menu>ul>li.menu-item-has-children a {
  padding-right: 17px !important;
}

.counter li {
  padding-bottom: 40px !important;
  padding-top: 40px !important;
}

.counter span {
  font-size: 2.3em !important;
}

.counter div {
  font-size: 0.8em !important;
  margin-top: 10px !important;
}

.equipoBtn {

  font-weight: bold;
  text-transform: uppercase;
  margin: 0 1em 0 0;
  font-size: 1em;
}

.btn {
  margin-bottom: -20px !important;
  margin-top: 20px;
}

.btn.btn-lg {
  font-size: 0.7em !important;
  margin-top: 0;
  padding: 14px 40px !important;
  color: #666
}

.btn:hover {
  border: 1px solid #aaa !important
}

h2.title {
  font-size: 2em !important;
}

@media screen and (max-width: 1366px) {
  h2.title {
    font-size: 2.2em;
  }
}

@media screen and (max-width: 1280px) {
  h2.title {
    font-size: 2em;
  }
}

@media screen and (max-width: 1024px) {
  h2.title {
    font-size: 2.1em;
  }
}

main {

  margin-top: 5.8em !important;
}

.textwidget {
  z-index: auto !important;
}

#pg-205-1,
#pg-205-3 {
  margin-bottom: 0 !important;

}

#pg-205-0 {
  margin-bottom: 0em !IMPORTANT;
}

.panel-grid {
  margin-bottom: 58px !important;
}

#pg-56-2 {
  margin-bottom: 98px !important;
}

p {
  text-align: left !important;
  font-size: 0.8em;
  font-family: 'Trebuchet MS' !important;
  color: #777 !important
}

@media screen and (max-width: 1366px) {
  p {
    font-size: 0.75em;
  }

  .color p {
    font-size: 0.7em !important;
  }

  #panel-56-5-1-1 p {
    /*** Edicion Anto FIX para evitar que se achique el texto de Proyectos en la Intro ***/
    font-size: 0.8em !important;
  }
}

@media screen and (max-width: 1280px) {
  p {
    font-size: 0.8em;
  }

  .color p {
    font-size: 0.7em !important;
  }
}

@media screen and (max-width: 1024px) {
  p {
    font-size: 0.72em;
  }
}

@media (min-width: 1500px) {
  title {
    margin-top: -140px !important;
  }
}

.text-padding p {
  margin-bottom: 0 !important
}

.title::before {
  top: 110px !important;
}

.site-header .nav-menu a {
  font-weight: 700 !important;
  font-size: 0.9em;
  font-family: 'Open Sans' !important;
  color: #000 !important
}

.nav-sticky.nav-scroll .site-header .nav-row {
  background: #fff !important
}

.nav-desktop .site-header .nav-menu {
  padding-top: 10px !important;
}

.nav-desktop .site-header .nav-menu .sub-menu a:hover {
  background-color: #fff !important;
}

.nav-desktop .site-header .nav-menu>ul>li:hover:before {
  display: none
}

.nav-desktop.nav-sticky.nav-scroll-active .site-header .nav-menu .sub-menu {
  top: 31px !important
}

.nav-desktop .site-header .nav-menu .sub-menu {
  top: 56px !important
}

.site.style-2 {
  background-color: #fff !important
}

.tp-bullet,
.zeus .tp-bullet {
  width: 6px;
  height: 6px;
  background: #fff;
  border: 2px solid transparent;
  margin: 1px !important;
  text-indent: -9000px
}

.selected,
.zeus .selected {
  width: 8px !important;
  height: 8px !important;
  background: none !important;
  border: 2px solid #fff !important;
  margin: 0 !important;
}

.tp-bullet:after,
.zeus .tp-bullet:after {
  background: none !important;
}

.blog-masonry .page-nav {
  margin-top: 0 !important
}

.blog-masonry .page-nav a {
  padding: 0 !important
}

.page-numbers {
  text-align: center
}

.page-numbers li a {
  width: 10px;
  height: 10px;
  background: #333 !important;
  border: 2px solid transparent !important;
  margin: 1px !important;
  text-indent: -9000px;
  border-radius: 50%;
  padding: 0 !important
}

.page-numbers li {
  border: 0 !important;
  background: none !important
}

.page-numbers li span.current {
  width: 12px !important;
  height: 12px !important;
  background: none !important;
  border: 2px solid #333 !important;
  margin: 0 !important;
  text-indent: -9000px;
  border-radius: 50%;
  padding: 0 !important;
  position: relative;
  top: -1px;
}

.page-numbers li a.prev,
.page-numbers li a.next {
  display: none !important
}

.tp-caption {
  font-family: 'Open Sans' !important;
}

.slider-home-top .tp-caption.BigBold-Title,
.slider-home-top .BigBold-Title,
.slider-team-top .tp-caption.BigBold-Title,
.slider-team-top .BigBold-Title {
  color: #fff;
  font: 700 2.5em/100% 'Open Sans' !important;
  text-align: center;
  max-width: 100% !important;
}

.slider-home-top .tp-caption.noshadow,
.slider-team-top .tp-caption.noshadow {
  font-family: 'Open Sans' !important;
  font-size: 1.7em !important;
  font-weight: 400 !important;
  line-height: 130% !important;
  max-width: 80% !important;
  min-width: 80% !important;
  margin: 0 auto !important
}

.slider-home-top .tp-parallax-wrap,
.slider-team-top .tp-parallax-wrap {
  left: 0 !important;
  width: 100% !important
}

.slider-home-top .tp-loop-wrap,
.slider-home-top .tp-mask-wrap,
.slider-team-top .tp-loop-wrap,
.slider-team-top .tp-mask-wrap {
  position: relative !important;
}

.slider-home-top .tp-parallax-wrap .tp-caption.BigBold-SubTitle,
.slider-team-top .tp-parallax-wrap .tp-caption.BigBold-SubTitle {
  font: 300 1.5em/100% 'Open Sans' !important;
  color: #fff;
  text-align: center;
  top: -15px !important;
  position: relative;
  max-width: 100% !important;
}

.slider-history-top .Fashion-BigDisplay {
  font-family: 'Open Sans' !important;
  font-size: 1.7em !important;
  font-weight: 400 !important;
  line-height: 130% !important;
}

.tp-bullets {
  margin-left: -31px !important;
  top: 95% !important;
  transform: none !important;
}

blockquote.style-2 {
  font-size: 1.6em !important;
  /*** Edicion Anto, Valor anterior: 1.5em ***/
  line-height: 140%;
  font-weight: 400;
  margin: 0 0 40px !important
}

@media (max-width: 1366px) {
  blockquote.style-2 {
    font-size: 1.7em !important;
  }
}

.counter span {
  color: #222 !important
}

.counter div {
  color: #777;
  font-weight: 400 !important;
  letter-spacing: -0.03em;
}

.title {
  margin-top: -140px !important;
  padding-top: 133px !important;
  margin-bottom: 20px !important;
}

.team-title .title {
  margin-top: -125px !important;
  padding-bottom: 45px !important;
}

.team-interior .team {
  padding-bottom: 55px !important;
  padding-top: 90px !important;
  margin-top: -30px !important;
}

@media (max-width: 767px) {

  .team-interior .team {
    padding-bottom: 0 !important;

    border-bottom: 0 !important;
  }

  #menu-item-8470,
  #menu-item-10324 {
    position: relative;
    top: auto;
    right: auto;
  }

  .site-header .nav-menu a {
    color: #999 !important;
  }
}

.portfolio {
  margin: 0 0 0 7px;
  clear: left;
  top: -275px;
  padding-top: 20%;
  margin-bottom: -275px !important;
}

.portfolio.portfolio-masonry-spacing article {
  position: relative !important;
  float: left;
  left: auto !important;
  top: auto !important;
}

.portfolio.portfolio-masonry-spacing article a {
  margin: 7px;
}

.portfolio.portfolio-hover-style-2 .hover {
  bottom: 22px !important;
  left: 22px !important;
  right: 22px !important;
  top: 22px !important;
}

.portfolio.portfolio-hover-style-2 a:hover .hover {
  opacity: 0.85;
}

.portfolio.portfolio-masonry-spacing article .hover::after {
  display: none
}

.portfolio .hover h5 {
  font-size: 24px !important;
  font-family: 'Open Sans';
  line-height: 1.2;
  color: #222;

  margin-bottom: 10px !important;

}

.portfolio .hover span {
  line-height: 20px;
  font-size: 16px;
}

.portfolio.portfolio-masonry-spacing article {
  width: 25% !important;
}

.portfolio.portfolio-masonry-spacing article.portfolio-large {}

.portfolio.portfolio-masonry-spacing article:nth-child(3) {
  /*margin-top: -18.7%;*/
}

.portfolio-post-header.no-background {
  margin-top: -140px !important;
}

.portfolio-post-header-heading {
  font-size: 2.5em !important;
  font-family: 'Open Sans';
  color: #222 !important;
  font-weight: 700 !important;
  border-bottom: 1px solid #ccc;
  padding: 0 0 20px;
}

.portfolio-post-header-content .portfolio-post-header-heading {
  font-size: 2.5em !important;
  color: #fff !important;
  text-transform: uppercase;
  text-align: center;
  border-bottom: 0
}

.no-bg {
  padding-top: 30px !important
}

.no-bg .portfolio-post-header-heading {
  display: none
}

.portfolio-post-header.no-background~.no-bg .portfolio-post-header-heading {
  display: block
}

.portfolio-post-header-heading-small {
  font-size: 1.9em !important;
  font-family: 'Open Sans';
  color: #222 !important;
  font-weight: 700 !important;
  border-bottom: 1px solid #ccc;
  padding: 0 0 20px;
  margin: 0 0 15px !important;
}

.portfolio-post-header-heading-small small {
  font-size: 0.6em !important;
  color: #222 !important;
  display: none !important;
  font-weight: bold !important;
}

.site .container .portfolio-post-header-meta li {
  font-size: 0.7em;
  font-family: 'Open Sans';
  color: #222 !important;
  display: block;
  font-style: normal !important;
}


.portfolio-post-header-heading-small small strong,
.portfolio-post-header-meta li.none {
  display: none !important
}

.portfolio-post-header-meta li.superficier,
.portfolio-post-header-meta li.plazo_de_la_obra {
  border-bottom: 1px solid #ccc;
  display: inline-block !important;
  width: 50%;
  font-size: 1em !important;
  padding-bottom: 15px;
  margin-bottom: 15px
}

.portfolio-post-header-meta li+li {
  margin-left: 0 !important;
}

.portfolio-post-header-meta strong {
  color: #222 !important;
  font-weight: bold !important;
}

.portfolio-nav {
  border: 0 !important;
  width: 100% !important;
  padding-bottom: 120px !important;
}

.portfolio-nav .prev,
.portfolio-nav .next {
  display: none
}

.portfolio-single-description {
  width: 100% !important;
}

.proyectos-relacionados {
  padding-bottom: 60px;
  clear: left;
}

.proyectos-relacionados-items {
  margin: 0 -7px
}

.proyectos-relacionados .portfolio-item {
  float: left;
  width: 33% !important;
}

.proyectos-relacionados .portfolio-item a {
  display: block;
  margin: 0 7px;
  position: relative
}

.proyectos-relacionados .portfolio-item a .hover {
  position: absolute;
  background-color: rgba(255, 255, 255, 1);
  bottom: 10px;
  left: 10px;
  right: 10px;
  top: 10px;
  z-index: 1;
  opacity: 0;
  -webkit-transition: .4s all;
  transition: .4s all;
  text-align: center;
}

.proyectos-relacionados .portfolio-item a:hover .hover {
  opacity: 0.85;
}

.proyectos-relacionados .portfolio-item .hover .hover-content {
  -webkit-transform: translateX(-50%) translateY(-50%);
  transform: translateX(-50%) translateY(-50%);
  left: 50%;
  position: absolute;
  top: 50%;
  width: 90%;
}

.proyectos-relacionados .portfolio-item a:hover span,
.proyectos-relacionados .portfolio-item a:hover h5 {
  opacity: 1;
  -webkit-transform: translateY(0);
  -ms-transform: translateY(0);
  transform: translateY(0);
}

.proyectos-relacionados .portfolio-item .hover h5 {
  font-size: 1.5em !important;
  font-family: 'Open Sans';
  line-height: 22px;
  color: #222;
  opacity: 0;
  margin-bottom: 14px;
  -webkit-transform: translateY(-80px) translateZ(0);
  transform: translateY(-80px) translateZ(0);
  -webkit-transition: .4s all;
  transition: .4s all;
}

.gallery {
  margin-top: 2%
}

.gallery-item a {
  margin: 7px;
}

.gallery-item:nth-child(3),
.gallery-item:nth-child(5) {
  width: 50% !important
}

.gallery-item:nth-child(3) {
  margin-top: -18.7%;
}

.gallery-item:nth-child(8) {
  margin-top: -19.3%;
}

.social {
  text-align: center;
  color: #fff !important;
}

.social strong {
  display: block;
  color: #fff !important;
  font-size: 1.3em;
}

.social a {
  color: #fff !important;
}

.social {
  text-align: center;
}

.panel-widget-style-home .sow-features-list .sow-features-feature {
  position: relative;
  text-align: left !important;
  margin-bottom: 0 !important;
  padding: 0 25px !important;
}

.panel-widget-style-home .sow-features-list .sow-features-feature .sow-icon-container {
  position: absolute;
  top: 50%;
  margin-top: -42px;
}

.panel-widget-style-home .sow-features-list .sow-features-feature p {
  padding: 0;
  color: #fff !important;
}

.panel-widget-style-home .sow-features-list .sow-features-feature h5 {
  color: #fff !important;
  font-weight: 700 !important;
  font-size: 0.95em !important;
  line-height: 100% !important;
  text-transform: none !important;
  margin: 0 0 15px !important;
  /*** Edicion Anto Valor anterior Bottom: 10px ***/
  text-indent: 0 !important
}

@media screen and (max-width: 1366px) {
  .panel-widget-style-home .sow-features-list .sow-features-feature h5 {
    font-size: 0.9em;
  }
}

@media screen and (max-width: 1280px) {
  .panel-widget-style-home .sow-features-list .sow-features-feature h5 {
    font-size: 0.9em;
  }
}

.panel-widget-style-home .sow-features-list .sow-features-feature .sow-icon-container {
  color: #fff !important
}

.sow-features-list .sow-features-feature .sow-icon-container [class^="sow-icon-"],
.sow-features-list .sow-features-feature .sow-icon-container .sow-icon-image {
  margin-top: 0;
  margin-left: 0;
  background-size: 100%;
}

.panel-widget-style-home .sow-features-list .sow-features-feature .sow-icon-container .sow-icon-fontawesome,
.panel-widget-style-interna .sow-features-list .sow-features-feature .sow-icon-container .sow-icon-fontawesome {
  background: url(bullets-home.png) 0 0 no-repeat;
  width: 100%;
  height: 100%;
  margin: -42px 0 0 -42px;
  text-indent: -9000px
}

.panel-widget-style-interna .sow-features-list .sow-features-feature .sow-icon-container .sow-icon-fontawesome {
  background: url(bullets-interna.png) 0 0 no-repeat;
}

.panel-widget-style-home .ico02 .sow-features-list .sow-features-feature .sow-icon-container .sow-icon-fontawesome,
.panel-widget-style-interna .ico02 .sow-features-list .sow-features-feature .sow-icon-container .sow-icon-fontawesome {
  background-position: 0 -84px
}

.panel-widget-style-home .ico03 .sow-features-list .sow-features-feature .sow-icon-container .sow-icon-fontawesome,
.panel-widget-style-interna .ico03 .sow-features-list .sow-features-feature .sow-icon-container .sow-icon-fontawesome {
  background-position: 0 -168px
}

.panel-widget-style-home .ico04 .sow-features-list .sow-features-feature .sow-icon-container .sow-icon-fontawesome,
.panel-widget-style-interna .ico04 .sow-features-list .sow-features-feature .sow-icon-container .sow-icon-fontawesome {
  background-position: 0 -252px
}

.panel-widget-style-home .ico05 .sow-features-list .sow-features-feature .sow-icon-container .sow-icon-fontawesome,
.panel-widget-style-interna .ico05 .sow-features-list .sow-features-feature .sow-icon-container .sow-icon-fontawesome {
  background-position: 0 -336px
}

.panel-widget-style-home .ico06 .sow-features-list .sow-features-feature .sow-icon-container .sow-icon-fontawesome,
.panel-widget-style-interna .ico06 .sow-features-list .sow-features-feature .sow-icon-container .sow-icon-fontawesome {
  background-position: 0 -420px
}

.panel-widget-style-home .ico07 .sow-features-list .sow-features-feature .sow-icon-container .sow-icon-fontawesome,
.panel-widget-style-interna .ico07 .sow-features-list .sow-features-feature .sow-icon-container .sow-icon-fontawesome {
  background-position: 0 -504px
}

.panel-widget-style-home .ico08 .sow-features-list .sow-features-feature .sow-icon-container .sow-icon-fontawesome,
.panel-widget-style-interna .ico08 .sow-features-list .sow-features-feature .sow-icon-container .sow-icon-fontawesome {
  background-position: 0 -588px
}

.panel-widget-style-home .ico09 .sow-features-list .sow-features-feature .sow-icon-container .sow-icon-fontawesome,
.panel-widget-style-interna .ico09 .sow-features-list .sow-features-feature .sow-icon-container .sow-icon-fontawesome {
  background-position: 0 -672px
}

.panel-widget-style-home .ico10 .sow-features-list .sow-features-feature .sow-icon-container .sow-icon-fontawesome,
.panel-widget-style-interna .ico10 .sow-features-list .sow-features-feature .sow-icon-container .sow-icon-fontawesome {
  background-position: 0 -756px
}

.panel-widget-style-home .ico11 .sow-features-list .sow-features-feature .sow-icon-container .sow-icon-fontawesome,
.panel-widget-style-interna .ico11 .sow-features-list .sow-features-feature .sow-icon-container .sow-icon-fontawesome {
  background-position: 0 -840px
}

.panel-widget-style-home .sow-features-list .sow-features-feature .textwidget {
  margin-left: 130px !important;
  min-height: 84px;
  border-bottom: 1px solid #E8455F;
  padding: 25px 0
}

.panel-widget-style-interna .sow-features-list .sow-features-feature .textwidget {
  min-height: 84px;
  padding: 25px 0 50px
}

.panel-widget-style-home .sow-features-list .sow-features-feature .sow-icon-container [class^="sow-icon-"],
.panel-widget-style-home .sow-features-list .sow-features-feature .sow-icon-container .sow-icon-image {
  color: #e21737 !important;
  font-size: 44px !important;
}

.panel-widget-style-interna .so-widget-sow-features .sow-features-feature {
  text-align: left
}

.panel-widget-style-interna .so-widget-sow-features .sow-features-list .sow-features-feature .sow-icon-container {
  float: left
}

.panel-widget-style-interna .so-widget-sow-features .sow-features-list .sow-features-feature .textwidget h5 {
  font-size: 1.5em !important;
  font-family: 'Open Sans';
  line-height: 100%;
  color: #222;
  text-transform: none;
  text-indent: 20px
}

.panel-widget-style-interna .so-widget-gfxbucket-visual-editor ul {
  padding-left: 15px;
  margin-bottom: 20px;
}

.panel-widget-style-interna .so-widget-gfxbucket-visual-editor ul li {
  color: #777;
  font-size: 0.8em;
  font-family: 'Trebuchet MS' !important;
}

.fixed-top {
  position: relative;
  z-index: 100
}

.fixed-top-affix {
  position: fixed;
  left: 0;
  top: 70px;
  width: 100%;
  margin: 0 !important;
  padding: 0 !important;
}

.admin-bar .fixed-top-affix {
  top: 106px;
}

.counter {
  margin-bottom: 70px;
}

.color {
  padding-bottom: 70px;
}

.color h2.title {
  color: #fff;
  margin-top: 0 !important;
  padding-top: 100px !important;
}

.talk-home h3 {
  margin-top: -15px;
  margin-bottom: 25px;
}

.color h2.title:before {
  background-color: #fff;
  top: 70px !important;
}

.color h3.section-title {
  color: #fff !important;
  font-size: 2em !important;
  margin-top: -15px;
  margin-bottom: 25px;
}

@media screen and (max-width: 1366px) {
  .color h3.section-title {
    font-size: 2.1em !important;
  }
}

@media screen and (max-width: 1280px) {
  .color h3.section-title {
    font-size: 2.05em !important;
  }
}

@media screen and (max-width: 1024px) {
  .color h3.section-title {
    font-size: 2.1em !important;
  }
}

@media screen and (max-width: 767px) {
  .color h3.section-title {
    font-size: 1.5em !important;
  }
}

.color .contact-down,
.contact-down {
  text-align: center;
}

.color .contact-home {
  display: none;
  -webkit-transition: -webkit-transform 0.2s, opacity 0.3s;
  -moz-transition: -moz-transform 0.2s, opacity 0.3s;
  transition: transform 0.2s, opacity 0.3s;
}

.color .contact-home .wpcf7-form {
  width: 70%;
  margin: 40px auto 0;
}

.color-grey h3.section-title {
  color: #333 !important
}

.team-home .team {
  border-bottom: 0 !important
}

.team {
  padding-bottom: 55px !important;
  padding-top: 0 !important;
  margin-top: -30px !important
}

.team .member-image {
  -webkit-transition: -webkit-transform 0.2s, opacity 0.3s;
  -moz-transition: -moz-transform 0.2s, opacity 0.3s;
  transition: transform 0.2s, opacity 0.3s;
  opacity: 1
}

.team .member-image:hover {}

.team .member-image:before,
.team .member h3:after {
  display: none !important;
}

.team .member-image:after {
  bottom: 16.5% !important;
}

.team .member h3 {
  font-size: 1em !important;
  white-space: nowrap;
  padding-top: 20px !important;
}

.team .member em {
  font-size: 0.8em !important;
  display: inline-block !important;
  min-height: 35px;
}

.team .team-social:after {
  content: "";
  bottom: -15px;
  background-color: #DADADA;
  left: 5%;
  height: 1px;
  position: absolute;
  width: 90%;
}

h2.heading {
  font-size: 2.1em;
  /*** Edicion Anto Valor anterior: 2 em ***/
  line-height: 100% !important;
  color: #222;
  text-transform: none !important;
  text-align: center;
}

.title-team {
  margin-bottom: -90px;
  padding-top: 25px;
}

.title-team .title {
  margin-top: -125px !important;
  padding-top: 145px !important;
  padding-bottom: 30px;
}

@media screen and (max-width: 767px) {
  .title-team .title {
    font-size: 1.6em !important;
    text-align: center !important;
  }
}

/*.more {
    line-height: 40px;
    border-top: 1px solid rgb(221, 221, 221);
    border-bottom: 1px solid rgb(221, 221, 221);
    padding-right: 20px;
}*/
a.more {
  font-size: 10px;
}

a.more:after {

  position: absolute;

  right: -15px;

  top: 49%;

}

@media screen and (max-width: 1366px) {
  a.more {
    font-size: 10px;
  }
}

@media screen and (max-width: 1280px) {
  a.more {
    font-size: 10px;
  }
}

@media screen and (max-width: 1024px) {
  a.more {
    font-size: 9px;
  }
}

.filter {
  margin: 0 auto;
  background: #e5e5e5;
  border-top: 1px solid #ccc
}

.filter .text-left {
  float: left
}

.filter .text-right {
  float: right;
  line-height: 55px;
}

.filter-white {
  background: #fff !important;
  padding: 15px 0
}

.filter .equipoBtn,
.filter button {
  position: relative;
  font-size: 0.7em !important;
  padding: 0 10px !important;
  line-height: 33px !important;
}

.filter button {
  margin: 10px 5px !important
}

.filter .equipoBtn.active,
.filter button.selected {
  color: #E21737 !important
}

.filter .equipoBtn.active:after,
.filter button.selected:after {
  border-left: 4px solid transparent;
  border-right: 4px solid transparent;
  border-top: 4px solid #E21737;
  content: "";
  height: 0px;
  margin-top: -8px;
  position: absolute;
  right: -5px;
  top: 100%;
  transition: all 0.5s ease 0s;
  width: 0px;
}

.filter-select {
  margin: 0 auto;
  text-align: center;
  border-bottom: 1px solid #fff;
  border-top: 0 !important;
  padding-bottom: 13px
}

.filter-select select {
  position: relative;
  padding: 0 10px !important;
  width: auto !important
}

.styled-select select {
  background: none !important;
  width: 128px !important;
  padding: 5px !important;
  font-size: 0.7em !important;
  line-height: 1;
  border: 0;
  border-radius: 0;
  height: 34px;
  -webkit-appearance: none;
  max-width: none !important;
  font-weight: bold;
  text-transform: uppercase;
  position: relative;

  z-index: 10;

}

.styled-select {
  position: relative !important;
  width: 60px;
  height: 34px;
  overflow: hidden;
  display: inline-block;
  margin-right: 15px;
  top: 12px !important;
}

.styled-select2 {
  width: 60px;
}

div.styled-select.styled-select3,
.styled-select3 {
  width: 110px;
}

.styled-select4 {
  width: 155px !important;
}

.styled-select4 select {
  width: 178px !important;
}

.styled-select:after {
  border-left: 4px solid transparent;
  border-right: 4px solid transparent;
  border-top: 4px solid #333;
  content: "";
  height: 0px;
  margin-top: -19px;
  position: absolute;
  right: 0;
  top: 100%;
  transition: all 0.5s ease 0s;
  width: 0px;
  z-index: 2
}

.styled-select:before {
  content: "";
  height: 22px;
  position: absolute;
  right: 0;
  top: 0;
  width: 15px;
  background: #e5e5e5;
  z-index: 1
}

.filter-white .styled-select:before {
  background: #fff
}

.filter-select a#FiltroButton {
  font-size: 0.7em !important;
  font-weight: bold !important;
  height: 54px;
  padding: 8px 20px !important;
  text-transform: uppercase;
  background: #E21737;
  color: #fff;
  border-radius: 4px;
}

/*
@media screen and (min-color-index:0) and(-webkit-min-device-pixel-ratio:0)
{ @media {
	.filter-select a#FiltroButton,
	.filter-link,
	.styled-select {
		position: relative;
		top: 7px !important
	}
}}*/
.filter-link {
  padding-left: 40px;
  margin-left: 40px;
  border-left: 1px solid #ccc;
  display: inline-block
}

.blog-container {
  border-top: 1px solid #DADADA
}

.blog-home .blog-wrapper {
  padding-bottom: 25px;
  margin-left: 0 !important;
  margin-right: 0 !important;
}

.blog-home .blog-posts {
  border: 1px solid #DADADA !important;
  width: 48%;
  float: left;
  margin: 1% 1% 1% 0;
  padding-bottom: 0 !important;
  overflow: hidden
}

.blog-masonry .blog-posts {
  margin-bottom: 30px !important;
}

.blog-masonry .blog-post-comments-link .fa~.fa {
  margin-left: 7px !important
}

.blog-home .blog-posts+.blog-posts,
.blog-home .blog-posts+.blog-posts+.blog-posts+.blog-posts,
.blog-home .blog-posts+.blog-posts+.blog-posts+.blog-posts+.blog-posts+.blog-posts {
  margin-top: 1% !important;
  margin-left: 1%;
  margin-right: 0;
  float: right;
}

.blog-home .blog-posts+.blog-posts+.blog-posts,
.blog-home .blog-posts+.blog-posts+.blog-posts+.blog-posts+.blog-posts {
  margin-left: 0;
  margin-right: 1%;
  float: left;
}

.blog-home .blog-posts a,
.blog-home .blog-posts .blog-post-content,
.blog-home .blog-posts footer {
  width: 50%;
  float: left;
  padding-left: 4%;
  padding-right: 4%
}

.blog-home .blog-posts .blog-post-image {
  position: absolute !important;
  width: 100%;
  z-index: 1;
  padding-left: 0;
  padding-right: 0;
  top: 0
}

.blog-home .blog-posts .blog-post-image img {
  border: 0 !important;
}

.blog-home .blog-posts .blog-post-content {
  z-index: 2;
  opacity: 1;
  position: relative;
  background: rgba(255, 255, 255, 0.9) none repeat scroll 0% 0%;
  float: right;
  padding-top: 80px;
  min-height: 218px
}

.blog-home .blog-posts .blog-post-content p,
.blog-interior .blog-posts .blog-post-content p {
  display: none
}

.blog-home .blog-posts .blog-post-content p:first-child,
.blog-interior .blog-posts .blog-post-content p:first-child {
  position: relative;
  display: block;
}

.blog-home .blog-posts a.more {
  width: 100%;
  float: none;
  padding-left: 0;
  padding-right: 0;
  font-size: 0.6em;
  font-family: 'Open Sans';
  color: #222;
  border: 0 !important;
  margin: 10px 20px 0 0 !important;
  text-align: center;
}

.blog-posts a.more {
  border: 0 !important
}

.blog-home .blog-posts a.more:after {
  right: -5px !important;
}

.blog-home .blog-posts header a {
  position: absolute;
  top: -15px;
  right: 0px;
  z-index: 10;
}

.blog-home .blog-posts footer {
  position: absolute !important;
  bottom: 15px;
  right: 0;
  z-index: 2;
}

.blog-home .blog-posts .blog-post-comments-link {
  display: none
}

.blog-home .blog-posts .blog-post-title {
  font-size: 1.05em !important;
  line-height: 120%;
  color: #222;
  font-family: 'Open Sans';
  font-weight: 600
}

@media (max-width: 1366px) {
  .blog-home .blog-posts .blog-post-title {
    /*font-size: 0.6em !important;*/
    /*** Edicion Anto Valor anterior: 0.75em ***/
  }
}

.blog-home .blog-posts .blog-post-content {
  font: 0.8em/130% "Open Sans" !important;
  color: #616161 !important;
}

@media screen and (max-width: 1366px) {
  .blog-home .blog-posts .blog-post-content {
    font-size: 0.6em;
  }
}

@media screen and (max-width: 1280px) {
  .blog-home .blog-posts .blog-post-content {
    font-size: 0.9em;
  }
}

@media screen and (max-width: 1024px) {
  .blog-home .blog-posts .blog-post-content {
    font-size: 0.92em;
  }
}

.blog-home .blog-posts .blog-post-author-image,
.blog-home .blog-posts .blog-post-author {
  display: none
}

.blog-home .blog-posts a.more:after {
  content: "\f344";
  border: 0 !important;
  font-family: 'dashicons';
  top: 1px !important;
  display: none;
  position: relative !important;
}

.blog-home .blog-posts+.blog-posts header a,
.blog-home .blog-posts+.blog-posts+.blog-posts+.blog-posts header a,
.blog-home .blog-posts+.blog-posts+.blog-posts+.blog-posts+.blog-posts+.blog-posts header a,
.blog-home .blog-posts+.blog-posts footer,
.blog-home .blog-posts+.blog-posts+.blog-posts+.blog-posts footer,
.blog-home .blog-posts+.blog-posts+.blog-posts+.blog-posts+.blog-posts+.blog-posts footer {
  right: auto;
  left: 0
}

.blog-home .blog-posts+.blog-posts+.blog-posts header a,
.blog-home .blog-posts+.blog-posts+.blog-posts footer,
.blog-home .blog-posts+.blog-posts+.blog-posts+.blog-posts+.blog-posts header a,
.blog-home .blog-posts+.blog-posts+.blog-posts+.blog-posts+.blog-posts footer {
  right: 0;
  left: auto
}

.blog-home .blog-posts+.blog-posts .blog-post-content,
.blog-home .blog-posts+.blog-posts+.blog-posts+.blog-posts .blog-post-content,
.blog-home .blog-posts+.blog-posts+.blog-posts+.blog-posts+.blog-posts+.blog-posts .blog-post-content {
  float: left;
}

.blog-home .blog-posts+.blog-posts+.blog-posts .blog-post-content,
.blog-home .blog-posts+.blog-posts+.blog-posts+.blog-posts+.blog-posts .blog-post-content {
  float: right;
}

.blog-home .blog-posts+.blog-posts .blog-post-author,
.blog-home .blog-posts+.blog-posts+.blog-posts+.blog-posts .blog-post-author,
.blog-home .blog-posts+.blog-posts+.blog-posts+.blog-posts+.blog-posts+.blog-posts .blog-post-author {
  right: auto;
  left: 4%
}

.blog-home .blog-posts+.blog-posts+.blog-posts .blog-post-author,
.blog-home .blog-posts+.blog-posts+.blog-posts+.blog-posts+.blog-posts .blog-post-author {
  right: 0;
  left: auto
}

.team-text {
  padding-top: 78px !important;
  padding-bottom: 78px !important;
}

@media (max-width: 970px) {
  .blog-wrapper {
    margin-left: 0 !important;
    margin-right: 0 !important;
  }

  .blog-home .blog-posts {
    width: 100%;
    margin: 0 auto !important;
    float: none !important;
  }

  .blog-home .blog-posts a,
  .blog-home .blog-posts footer {
    position: relative !important;
    width: 100%;
  }

  .blog-home .blog-posts .blog-post-image {
    position: relative !important;
  }

  .blog-home .blog-posts .blog-post-content {
    display: none
  }

  .blog-home .blog-posts .blog-post-title {
    margin-bottom: 0 !important;
    margin-top: 30px !important;
  }

  .blog-home .blog-posts {
    padding-bottom: 0 !important;
    max-height: none !important;
    margin-bottom: 20px !important;
  }
}

.blog-interior .blog-post-author-details {
  text-align: left;
  color: rgb(136, 136, 136);
  font-size: 0.8em;
}

.blog-interior .blog-posts a.blog-post-comments-link {
  font-size: 0.8em;
  line-height: 22px;
}

.blog-interior .blog-posts .blog-post-image img {
  border: 0 !important
}

h3.widget-title {
  font-size: 2em !important;
  padding-left: 20px;
  padding-top: 30px
}

h3.widget-title:after {
  display: none !important
}

#rowsCasos {
  background: #e5e5e5;
  border: 0 !important;
  padding-top: 20px
}

#rowsCasos td {
  border: 0;
  border-bottom: 1px solid #ccc;
  padding-left: 20px;
  font-size: 0.9em;
  color: #777 !important
}

#rowsCasos td a {
  color: #777 !important
}

#rowsCasos .bolder td {
  font-size: 1.5em !important;
  font-weight: bold;
  color: #222 !important
}

.blog-clients {
  padding-top: 40px
}

.blog-clients .blog-wrapper {
  margin-left: -15px !important;
  margin-right: -15px !important;
}

.blog-clients .blog-post-comments-link,
.blog-clients .blog-post-author,
.blog-page .blog-post-author {
  display: none !important
}

.blog-clients .blog-post-content p:last-child {
  color: #999;
  font-size: 0.9em;
  font-weight: bold;
}

.blog-clients .blog-post-content p:last-child em {
  font-size: 0.75em;
  display: block;
  font-style: normal !important
}

.chart {
  margin-top: -3em;
}

.chart .panel-widget-style {
  position: relative
}

.chart h3.widget-title {
  font-size: 1.4em !important;
  text-align: center;
  width: 100%;
  margin: 0px auto !important;
  padding: 0px;
  position: absolute !important;
  top: 30% !important;
  left: auto;
}

.chart h3.widget-title small {
  color: #333 !important;
  display: block;
  font-size: 0.4em !important;
  text-transform: uppercase;
  font-weight: bold;
}

.chart .wp_charts_canvas {
  width: 111px !important;
  height: 111px !important;
  max-width: none !important;
}

.chart .wp-chart-wrap {
  width: 111px !important;
  height: 111px !important;
  text-align: center !important;
  margin: 20px auto !important;
}

@media (max-width: 767px) {
  .chart.container .panel-grid-cell {
    width: 100% !important
  }

  .chart h3.widget-title {
    font-size: 2.0em !important;
    top: 35% !important;
  }
}

.arrow-top {
  position: relative;
  padding-top: 60px !important;
  padding-bottom: 60px !important;
  clear: left;
  float: left;



  margin-top: -60px !important;
  /*width: 100% !important*/
}

.panel-grid .arrow-top:after {
  top: 0;
  left: 50%;
  border: solid transparent;
  content: " ";
  height: 0;
  width: 0;
  position: absolute;
  pointer-events: none;
  border-color: rgba(255, 255, 255, 0);
  border-top-color: #ffffff;
  border-width: 10px;
  margin-left: -10px;
}

.panel-grid:nth-child(even) .arrow-top:after {
  border-top-color: #e5e5e5;
}

.color-last {
  position: relative;
  z-index: 101
}

.color-last .panel-grid-cell:last-child {
  background: #d1d1d1;
  padding: 40px !important
}

.color-last .panel-grid-cell:last-child h2 {
  margin: 16px 0 !important
}

.color-last .panel-grid-cell:last-child p {
  margin-bottom: 10px !important;
}

.color-last .panel-grid-cell:last-child .social-contact {
  text-align: center;
  font-weight: bold;
  bottom: -25px;
  position: relative;
}

.color-last .panel-grid-cell:last-child .social {
  padding: 5px 0 0 !important
}

.color-last .panel-grid-cell:last-child .social a {
  color: #222 !important;
}

.video-interna {

  margin-top: -40px;

  position: relative;

}

.video-interna p strong,
.video-interna-box p strong {
  font-size: 1.5em !important;
  font-weight: bold;
  color: #222 !important;
  margin-bottom: 2em
}

.video-interna-box {
  border: 1px solid #ccc;
  border-top: 0;
  padding: 20px;
  min-height: 250px;
  margin-bottom: 2em
}

.video-interna-box p strong {
  margin-bottom: 0
}

.filtros strong {
  font-size: 0.9em;
  font-weight: bold;
  display: block
}

.filtros strong small {
  font-size: 0.8em;
  font-weight: normal;
}

.progress-wrap {
  margin-bottom: 10px !important;
  padding-top: 55px !important;
  padding-bottom: 0 !important;
}

.progress-wrap .progress-meta {
  display: none
}

.progress-wrap .progress-title {
  position: absolute;
  padding: 6px;
  color: #fff;
  font-size: 1em !important;
  font-weight: bold;
  text-transform: uppercase
}

.progress-wrap .progress {
  background-color: #afe0dd !important;
  border: 1px solid #45b3b0
}

.progress-wrap .progress-bar {
  background-color: #45b3b0 !important;
}

.color2 .progress-wrap .progress {
  background-color: #a9cee8 !important;
  border: 1px solid #2985c4
}

.color2 .progress-wrap .progress-bar {
  background-color: #2985c4 !important;
}

.color3 .progress-wrap .progress {
  background-color: #cbbbd8 !important;
  border: 1px solid #7e55a1
}

.color3 .progress-wrap .progress-bar {
  background-color: #7e55a1 !important;
}

.title-progress {
  position: absolute
}

.title-progress h2 {
  font-size: 1.3em !important;
  line-height: 50px !important;
}

.imageWp {
  position: relative
}

.imageWp .containerPresupuesto {
  position: absolute;
  left: 20%;
  top: 10%;
  background: rgba(255, 255, 255, 0.9);
  border-radius: 100%;
  width: 300px;
  height: 300px;
  text-align: center;
  padding-top: 70px
}

.imageWp .containerPresupuesto h2 {
  font-size: 1.0em;
}

.imageWp .containerPresupuesto h3 {
  font-size: 2em !important;
  margin-top: 15px !important;
}

.imageWp .containerPresupuesto a {
  background: rgba(255, 255, 255, 0.8);
  text-transform: uppercase
}

.single-post .blog-post-author {
  position: absolute;
  top: -95px;
  left: 25%;
  width: 100%;
  padding-bottom: 25px !important;
}

.single-post .blog-post-author-details {
  margin-top: -20px
}

.single-post article {
  margin-top: 60px
}

.single-post .recent-posts article {
  margin-bottom: 0 !important;

  margin-top: 0 !important
}

.single-post .recent-posts .blog-more {

  height: 220px;

  color: #222
}

.single-post .recent-posts .blog-more:hover {

  color: #fff
}

.page-cover input[type="text"] {
  width: 335px !important;
}

h2.section-title {
  margin-bottom: 20px !important;
  font-size: 2em;
}

@media screen and (max-width: 1366px) {
  h2.section-title {
    font-size: 2.2em;
  }
}

@media screen and (max-width: 1280px) {
  h2.section-title {
    font-size: 2em;
  }
}

@media screen and (max-width: 1024px) {
  h2.section-title {
    font-size: 2.1em;
  }
}

.title-center h2.section-title {
  margin-bottom: 60px !important;
  text-align: center !important
}

h3.section-title {
  text-align: center !important;
  padding-top: 50px !important
}

.title-light h3 {
  font-weight: 100 !important
}

input[type="text"],
input[type="email"],
input[type="tel"],
input[type="number"],
input[type="password"],
textarea,
select {
  border-radius: 5px !important;
}

select {
  background: #fff !important;
}

.talk-home {
  padding-bottom: 50px !important;
  clear: both !important;
  position: relative;
}

.wpcf7-submit {
  background: #e21737;
  width: 12%;
  /*** Edicion Anto Valor anterior: 30% ***/
  border: 0;
  border-radius: 5px;
  color: #fff;
  font: bold 0.9em/41px 'Lato';
  text-transform: uppercase;
  border: 1px solid #fff;
  margin-left: 45% !important;
  /*** Edicion Anto Valor anterior: 35% ***/
  margin-top: 5%;
  /*** Edicion Anto ***/
  margin-bottom: 6%;
  /*** Edicion Anto ***/
}

.site-footer .wpcf7-submit {
  width: 100%;
  margin: 0 !important;
}

.contact-down .btn {
  background: #fff;
  text-transform: uppercase;
}

.instagram-tags,
.instagram-author-tag,
.instagram-meta,
.instagram-follow {
  display: none !important
}

footer .container {
  padding: 0 !important;
  width: 100% !important
}

.site-footer>div {
  padding: 0 !important;
}

.footer-content {
  margin-top: 0 !important;
}

footer #gfxbucket-visual-editor-2 {
  margin-top: -420px;
  z-index: 3;
  position: relative;
}

footer #gfxbucket_social-2 {
  z-index: 3 !important;
  margin-top: -515px;
  position: absolute;
  left: auto;
  right: auto;
  width: 100%;
}

footer #gfxbucket_social-2 a {
  color: #fff !important
}

footer #gfxbucket-visual-editor-2 .so-widget-gfxbucket-visual-editor {
  margin-bottom: 0 !important
}

footer #gfxbucket-visual-editor-2 .so-widget-gfxbucket-visual-editor {
  font: bold 1em/110% 'Lato';
  color: #fff;
}

footer .instagram h5 {
  font-size: 1em;
}

footer .wpcf7-form {
  width: 50%;
  clear: both;
  margin: 0 auto;
}

footer .wpcf7-form p:nth-child(2) {
  width: auto;
  float: none;
  margin: 0;
  padding: 0
}

footer .wpcf7-form p:nth-child(3) {
  width: auto;
  float: none;
  margin: 0 0 100px 0;
}

footer .wpcf7-form input.wpcf7-validates-as-required {
  border: 1px solid #ccc;
  margin-bottom: 4px;
  background: none !important;
  height: 41px;
  color: #fff !important
}

footer .wpcf7-form input.wpcf7-validates-as-required::placeholder,
footer .wpcf7-form input.wpcf7-validates-as-required::placeholder:placeholder-shown {
  opacity: 1 !important;
  color: #fff !important;
}

footer .wpcf7-form input.wpcf7-submit {
  border: 0 !important;
  font-size: 1em !important;
  font-family: Lato;
  letter-spacing: .04em;
}

footer #gfxbucket-contact-form-7-2 {
  margin-top: 20px !important;
  clear: both;
  min-height: 130px;
  margin-bottom: 0;
  z-index: 3;
  position: relative;
}

footer .widget_text,
footer .widget_search {
  float: left;
  width: 24%;
  text-align: left;
  padding: 0 0 0 5%
}

footer h4 {
  font: bold 0.8em/100% 'Open Sans' !important;
  color: #e21737 !important;
}

footer .widget_text .textwidget {
  font: 600 0.7em/150% 'Open Sans';
  color: #e3e3e3;
}

footer .widget_text .textwidget a {
  color: #e3e3e3;
}

footer .widget_text .textwidget ul,
footer .widget_text .textwidget li {
  list-style: none;
  padding: 0;
  margin: 0
}

footer .widget_text .textwidget ul li ul li {
  float: left;
  width: 50%
}

.instagram-author-photo {

  border: 0 !important
}

.instagram-author-photo img {
  border-radius: 100%
}

.site-footer .widget_search input[type="text"],
.site-footer .widget-search input[type="text"] {
  border: 1px solid #ccc !important
}

.widget_search button,
.widget-search button {
  color: #fff !important;
}

.site-footer .copyright {
  color: rgb(77, 77, 77) !important;
  font-size: 0.75em !important;
  line-height: 4em !important;
}

.statement {
  padding-bottom: 280px !important;
}

.site-footer .footer-content .widget:first-of-type {
  margin-top: -121px !important;
}

.site-footer {
  /* margin-top: 120px !important;*/
}

.so-widget-gfxbucket-portfolio .filter {
  position: absolute;
  top: 120px;
  left: 0;
  width: 100%;
  background: #ececec;
}

.so-widget-gfxbucket-portfolio .filter ul {
  margin: 0 !important;
  padding: 0 !important;
}

.so-widget-gfxbucket-portfolio .filter button.selected::before {
  display: none
}

.so-widget-gfxbucket-portfolio .filter button {
  font: bold 1em "Lato";
  color: #333;
  text-transform: uppercase;
}

/********** animated css *****************/
.animatable {
  visibility: hidden;
  -webkit-animation-play-state: paused;
  -moz-animation-play-state: paused;
  animation-play-state: paused;
}

/* show objects being animated */
.animated {
  visibility: visible;

  -webkit-animation-fill-mode: both;
  -moz-animation-fill-mode: both;
  -ms-animation-fill-mode: both;
  -o-animation-fill-mode: both;
  animation-fill-mode: both;

  -webkit-animation-duration: 1s;
  -moz-animation-duration: 1s;
  -ms-animation-duration: 1s;
  -o-animation-duration: 1s;
  animation-duration: 1s;
}


/*!
Animate.css - http://daneden.me/animate
Version - 3.4.0
Licensed under the MIT license - http://opensource.org/licenses/MIT

Copyright (c) 2015 Daniel Eden
*/

.animated {
  -webkit-animation-duration: 1s;
  animation-duration: 1s;
  -webkit-animation-fill-mode: both;
  animation-fill-mode: both;
}

.animated.infinite {
  -webkit-animation-iteration-count: infinite;
  animation-iteration-count: infinite;
}

.animated.hinge {
  -webkit-animation-duration: 2s;
  animation-duration: 2s;
}

.animated.bounceIn,
.animated.bounceOut {
  -webkit-animation-duration: .75s;
  animation-duration: .75s;
}

.animated.flipOutX,
.animated.flipOutY {
  -webkit-animation-duration: .75s;
  animation-duration: .75s;
}

@-webkit-keyframes bounce {

  from,
  20%,
  53%,
  80%,
  to {
    -webkit-animation-timing-function: cubic-bezier(0.215, 0.610, 0.355, 1.000);
    animation-timing-function: cubic-bezier(0.215, 0.610, 0.355, 1.000);
    -webkit-transform: translate3d(0, 0, 0);
    transform: translate3d(0, 0, 0);
  }

  40%,
  43% {
    -webkit-animation-timing-function: cubic-bezier(0.755, 0.050, 0.855, 0.060);
    animation-timing-function: cubic-bezier(0.755, 0.050, 0.855, 0.060);
    -webkit-transform: translate3d(0, -30px, 0);
    transform: translate3d(0, -30px, 0);
  }

  70% {
    -webkit-animation-timing-function: cubic-bezier(0.755, 0.050, 0.855, 0.060);
    animation-timing-function: cubic-bezier(0.755, 0.050, 0.855, 0.060);
    -webkit-transform: translate3d(0, -15px, 0);
    transform: translate3d(0, -15px, 0);
  }

  90% {
    -webkit-transform: translate3d(0, -4px, 0);
    transform: translate3d(0, -4px, 0);
  }
}

@keyframes bounce {

  from,
  20%,
  53%,
  80%,
  to {
    -webkit-animation-timing-function: cubic-bezier(0.215, 0.610, 0.355, 1.000);
    animation-timing-function: cubic-bezier(0.215, 0.610, 0.355, 1.000);
    -webkit-transform: translate3d(0, 0, 0);
    transform: translate3d(0, 0, 0);
  }

  40%,
  43% {
    -webkit-animation-timing-function: cubic-bezier(0.755, 0.050, 0.855, 0.060);
    animation-timing-function: cubic-bezier(0.755, 0.050, 0.855, 0.060);
    -webkit-transform: translate3d(0, -30px, 0);
    transform: translate3d(0, -30px, 0);
  }

  70% {
    -webkit-animation-timing-function: cubic-bezier(0.755, 0.050, 0.855, 0.060);
    animation-timing-function: cubic-bezier(0.755, 0.050, 0.855, 0.060);
    -webkit-transform: translate3d(0, -15px, 0);
    transform: translate3d(0, -15px, 0);
  }

  90% {
    -webkit-transform: translate3d(0, -4px, 0);
    transform: translate3d(0, -4px, 0);
  }
}

.bounce {
  -webkit-animation-name: bounce;
  animation-name: bounce;
  -webkit-transform-origin: center bottom;
  transform-origin: center bottom;
}

@-webkit-keyframes flash {

  from,
  50%,
  to {
    opacity: 1;
  }

  25%,
  75% {
    opacity: 0;
  }
}

@keyframes flash {

  from,
  50%,
  to {
    opacity: 1;
  }

  25%,
  75% {
    opacity: 0;
  }
}

.flash {
  -webkit-animation-name: flash;
  animation-name: flash;
}

/* originally authored by Nick Pettit - https://github.com/nickpettit/glide */

@-webkit-keyframes pulse {
  from {
    -webkit-transform: scale3d(1, 1, 1);
    transform: scale3d(1, 1, 1);
  }

  50% {
    -webkit-transform: scale3d(1.05, 1.05, 1.05);
    transform: scale3d(1.05, 1.05, 1.05);
  }

  to {
    -webkit-transform: scale3d(1, 1, 1);
    transform: scale3d(1, 1, 1);
  }
}

@keyframes pulse {
  from {
    -webkit-transform: scale3d(1, 1, 1);
    transform: scale3d(1, 1, 1);
  }

  50% {
    -webkit-transform: scale3d(1.05, 1.05, 1.05);
    transform: scale3d(1.05, 1.05, 1.05);
  }

  to {
    -webkit-transform: scale3d(1, 1, 1);
    transform: scale3d(1, 1, 1);
  }
}

.pulse {
  -webkit-animation-name: pulse;
  animation-name: pulse;
}

@-webkit-keyframes rubberBand {
  from {
    -webkit-transform: scale3d(1, 1, 1);
    transform: scale3d(1, 1, 1);
  }

  30% {
    -webkit-transform: scale3d(1.25, 0.75, 1);
    transform: scale3d(1.25, 0.75, 1);
  }

  40% {
    -webkit-transform: scale3d(0.75, 1.25, 1);
    transform: scale3d(0.75, 1.25, 1);
  }

  50% {
    -webkit-transform: scale3d(1.15, 0.85, 1);
    transform: scale3d(1.15, 0.85, 1);
  }

  65% {
    -webkit-transform: scale3d(.95, 1.05, 1);
    transform: scale3d(.95, 1.05, 1);
  }

  75% {
    -webkit-transform: scale3d(1.05, .95, 1);
    transform: scale3d(1.05, .95, 1);
  }

  to {
    -webkit-transform: scale3d(1, 1, 1);
    transform: scale3d(1, 1, 1);
  }
}

@keyframes rubberBand {
  from {
    -webkit-transform: scale3d(1, 1, 1);
    transform: scale3d(1, 1, 1);
  }

  30% {
    -webkit-transform: scale3d(1.25, 0.75, 1);
    transform: scale3d(1.25, 0.75, 1);
  }

  40% {
    -webkit-transform: scale3d(0.75, 1.25, 1);
    transform: scale3d(0.75, 1.25, 1);
  }

  50% {
    -webkit-transform: scale3d(1.15, 0.85, 1);
    transform: scale3d(1.15, 0.85, 1);
  }

  65% {
    -webkit-transform: scale3d(.95, 1.05, 1);
    transform: scale3d(.95, 1.05, 1);
  }

  75% {
    -webkit-transform: scale3d(1.05, .95, 1);
    transform: scale3d(1.05, .95, 1);
  }

  to {
    -webkit-transform: scale3d(1, 1, 1);
    transform: scale3d(1, 1, 1);
  }
}

.rubberBand {
  -webkit-animation-name: rubberBand;
  animation-name: rubberBand;
}

@-webkit-keyframes shake {

  from,
  to {
    -webkit-transform: translate3d(0, 0, 0);
    transform: translate3d(0, 0, 0);
  }

  10%,
  30%,
  50%,
  70%,
  90% {
    -webkit-transform: translate3d(-10px, 0, 0);
    transform: translate3d(-10px, 0, 0);
  }

  20%,
  40%,
  60%,
  80% {
    -webkit-transform: translate3d(10px, 0, 0);
    transform: translate3d(10px, 0, 0);
  }
}

@keyframes shake {

  from,
  to {
    -webkit-transform: translate3d(0, 0, 0);
    transform: translate3d(0, 0, 0);
  }

  10%,
  30%,
  50%,
  70%,
  90% {
    -webkit-transform: translate3d(-10px, 0, 0);
    transform: translate3d(-10px, 0, 0);
  }

  20%,
  40%,
  60%,
  80% {
    -webkit-transform: translate3d(10px, 0, 0);
    transform: translate3d(10px, 0, 0);
  }
}

.shake {
  -webkit-animation-name: shake;
  animation-name: shake;
}

@-webkit-keyframes swing {
  20% {
    -webkit-transform: rotate3d(0, 0, 1, 15deg);
    transform: rotate3d(0, 0, 1, 15deg);
  }

  40% {
    -webkit-transform: rotate3d(0, 0, 1, -10deg);
    transform: rotate3d(0, 0, 1, -10deg);
  }

  60% {
    -webkit-transform: rotate3d(0, 0, 1, 5deg);
    transform: rotate3d(0, 0, 1, 5deg);
  }

  80% {
    -webkit-transform: rotate3d(0, 0, 1, -5deg);
    transform: rotate3d(0, 0, 1, -5deg);
  }

  to {
    -webkit-transform: rotate3d(0, 0, 1, 0deg);
    transform: rotate3d(0, 0, 1, 0deg);
  }
}

@keyframes swing {
  20% {
    -webkit-transform: rotate3d(0, 0, 1, 15deg);
    transform: rotate3d(0, 0, 1, 15deg);
  }

  40% {
    -webkit-transform: rotate3d(0, 0, 1, -10deg);
    transform: rotate3d(0, 0, 1, -10deg);
  }

  60% {
    -webkit-transform: rotate3d(0, 0, 1, 5deg);
    transform: rotate3d(0, 0, 1, 5deg);
  }

  80% {
    -webkit-transform: rotate3d(0, 0, 1, -5deg);
    transform: rotate3d(0, 0, 1, -5deg);
  }

  to {
    -webkit-transform: rotate3d(0, 0, 1, 0deg);
    transform: rotate3d(0, 0, 1, 0deg);
  }
}

.swing {
  -webkit-transform-origin: top center;
  transform-origin: top center;
  -webkit-animation-name: swing;
  animation-name: swing;
}

@-webkit-keyframes tada {
  from {
    -webkit-transform: scale3d(1, 1, 1);
    transform: scale3d(1, 1, 1);
  }

  10%,
  20% {
    -webkit-transform: scale3d(.9, .9, .9) rotate3d(0, 0, 1, -3deg);
    transform: scale3d(.9, .9, .9) rotate3d(0, 0, 1, -3deg);
  }

  30%,
  50%,
  70%,
  90% {
    -webkit-transform: scale3d(1.1, 1.1, 1.1) rotate3d(0, 0, 1, 3deg);
    transform: scale3d(1.1, 1.1, 1.1) rotate3d(0, 0, 1, 3deg);
  }

  40%,
  60%,
  80% {
    -webkit-transform: scale3d(1.1, 1.1, 1.1) rotate3d(0, 0, 1, -3deg);
    transform: scale3d(1.1, 1.1, 1.1) rotate3d(0, 0, 1, -3deg);
  }

  to {
    -webkit-transform: scale3d(1, 1, 1);
    transform: scale3d(1, 1, 1);
  }
}

@keyframes tada {
  from {
    -webkit-transform: scale3d(1, 1, 1);
    transform: scale3d(1, 1, 1);
  }

  10%,
  20% {
    -webkit-transform: scale3d(.9, .9, .9) rotate3d(0, 0, 1, -3deg);
    transform: scale3d(.9, .9, .9) rotate3d(0, 0, 1, -3deg);
  }

  30%,
  50%,
  70%,
  90% {
    -webkit-transform: scale3d(1.1, 1.1, 1.1) rotate3d(0, 0, 1, 3deg);
    transform: scale3d(1.1, 1.1, 1.1) rotate3d(0, 0, 1, 3deg);
  }

  40%,
  60%,
  80% {
    -webkit-transform: scale3d(1.1, 1.1, 1.1) rotate3d(0, 0, 1, -3deg);
    transform: scale3d(1.1, 1.1, 1.1) rotate3d(0, 0, 1, -3deg);
  }

  to {
    -webkit-transform: scale3d(1, 1, 1);
    transform: scale3d(1, 1, 1);
  }
}

.tada {
  -webkit-animation-name: tada;
  animation-name: tada;
}

/* originally authored by Nick Pettit - https://github.com/nickpettit/glide */

@-webkit-keyframes wobble {
  from {
    -webkit-transform: none;
    transform: none;
  }

  15% {
    -webkit-transform: translate3d(-25%, 0, 0) rotate3d(0, 0, 1, -5deg);
    transform: translate3d(-25%, 0, 0) rotate3d(0, 0, 1, -5deg);
  }

  30% {
    -webkit-transform: translate3d(20%, 0, 0) rotate3d(0, 0, 1, 3deg);
    transform: translate3d(20%, 0, 0) rotate3d(0, 0, 1, 3deg);
  }

  45% {
    -webkit-transform: translate3d(-15%, 0, 0) rotate3d(0, 0, 1, -3deg);
    transform: translate3d(-15%, 0, 0) rotate3d(0, 0, 1, -3deg);
  }

  60% {
    -webkit-transform: translate3d(10%, 0, 0) rotate3d(0, 0, 1, 2deg);
    transform: translate3d(10%, 0, 0) rotate3d(0, 0, 1, 2deg);
  }

  75% {
    -webkit-transform: translate3d(-5%, 0, 0) rotate3d(0, 0, 1, -1deg);
    transform: translate3d(-5%, 0, 0) rotate3d(0, 0, 1, -1deg);
  }

  to {
    -webkit-transform: none;
    transform: none;
  }
}

@keyframes wobble {
  from {
    -webkit-transform: none;
    transform: none;
  }

  15% {
    -webkit-transform: translate3d(-25%, 0, 0) rotate3d(0, 0, 1, -5deg);
    transform: translate3d(-25%, 0, 0) rotate3d(0, 0, 1, -5deg);
  }

  30% {
    -webkit-transform: translate3d(20%, 0, 0) rotate3d(0, 0, 1, 3deg);
    transform: translate3d(20%, 0, 0) rotate3d(0, 0, 1, 3deg);
  }

  45% {
    -webkit-transform: translate3d(-15%, 0, 0) rotate3d(0, 0, 1, -3deg);
    transform: translate3d(-15%, 0, 0) rotate3d(0, 0, 1, -3deg);
  }

  60% {
    -webkit-transform: translate3d(10%, 0, 0) rotate3d(0, 0, 1, 2deg);
    transform: translate3d(10%, 0, 0) rotate3d(0, 0, 1, 2deg);
  }

  75% {
    -webkit-transform: translate3d(-5%, 0, 0) rotate3d(0, 0, 1, -1deg);
    transform: translate3d(-5%, 0, 0) rotate3d(0, 0, 1, -1deg);
  }

  to {
    -webkit-transform: none;
    transform: none;
  }
}

.wobble {
  -webkit-animation-name: wobble;
  animation-name: wobble;
}

@-webkit-keyframes jello {

  from,
  11.1%,
  to {
    -webkit-transform: none;
    transform: none;
  }

  22.2% {
    -webkit-transform: skewX(-12.5deg) skewY(-12.5deg);
    transform: skewX(-12.5deg) skewY(-12.5deg);
  }

  33.3% {
    -webkit-transform: skewX(6.25deg) skewY(6.25deg);
    transform: skewX(6.25deg) skewY(6.25deg);
  }

  44.4% {
    -webkit-transform: skewX(-3.125deg) skewY(-3.125deg);
    transform: skewX(-3.125deg) skewY(-3.125deg);
  }

  55.5% {
    -webkit-transform: skewX(1.5625deg) skewY(1.5625deg);
    transform: skewX(1.5625deg) skewY(1.5625deg);
  }

  66.6% {
    -webkit-transform: skewX(-0.78125deg) skewY(-0.78125deg);
    transform: skewX(-0.78125deg) skewY(-0.78125deg);
  }

  77.7% {
    -webkit-transform: skewX(0.390625deg) skewY(0.390625deg);
    transform: skewX(0.390625deg) skewY(0.390625deg);
  }

  88.8% {
    -webkit-transform: skewX(-0.1953125deg) skewY(-0.1953125deg);
    transform: skewX(-0.1953125deg) skewY(-0.1953125deg);
  }
}

@keyframes jello {

  from,
  11.1%,
  to {
    -webkit-transform: none;
    transform: none;
  }

  22.2% {
    -webkit-transform: skewX(-12.5deg) skewY(-12.5deg);
    transform: skewX(-12.5deg) skewY(-12.5deg);
  }

  33.3% {
    -webkit-transform: skewX(6.25deg) skewY(6.25deg);
    transform: skewX(6.25deg) skewY(6.25deg);
  }

  44.4% {
    -webkit-transform: skewX(-3.125deg) skewY(-3.125deg);
    transform: skewX(-3.125deg) skewY(-3.125deg);
  }

  55.5% {
    -webkit-transform: skewX(1.5625deg) skewY(1.5625deg);
    transform: skewX(1.5625deg) skewY(1.5625deg);
  }

  66.6% {
    -webkit-transform: skewX(-0.78125deg) skewY(-0.78125deg);
    transform: skewX(-0.78125deg) skewY(-0.78125deg);
  }

  77.7% {
    -webkit-transform: skewX(0.390625deg) skewY(0.390625deg);
    transform: skewX(0.390625deg) skewY(0.390625deg);
  }

  88.8% {
    -webkit-transform: skewX(-0.1953125deg) skewY(-0.1953125deg);
    transform: skewX(-0.1953125deg) skewY(-0.1953125deg);
  }
}

.jello {
  -webkit-animation-name: jello;
  animation-name: jello;
  -webkit-transform-origin: center;
  transform-origin: center;
}

@-webkit-keyframes bounceIn {

  from,
  20%,
  40%,
  60%,
  80%,
  to {
    -webkit-animation-timing-function: cubic-bezier(0.215, 0.610, 0.355, 1.000);
    animation-timing-function: cubic-bezier(0.215, 0.610, 0.355, 1.000);
  }

  0% {
    opacity: 0;
    -webkit-transform: scale3d(.3, .3, .3);
    transform: scale3d(.3, .3, .3);
  }

  20% {
    -webkit-transform: scale3d(1.1, 1.1, 1.1);
    transform: scale3d(1.1, 1.1, 1.1);
  }

  40% {
    -webkit-transform: scale3d(.9, .9, .9);
    transform: scale3d(.9, .9, .9);
  }

  60% {
    opacity: 1;
    -webkit-transform: scale3d(1.03, 1.03, 1.03);
    transform: scale3d(1.03, 1.03, 1.03);
  }

  80% {
    -webkit-transform: scale3d(.97, .97, .97);
    transform: scale3d(.97, .97, .97);
  }

  to {
    opacity: 1;
    -webkit-transform: scale3d(1, 1, 1);
    transform: scale3d(1, 1, 1);
  }
}

@keyframes bounceIn {

  from,
  20%,
  40%,
  60%,
  80%,
  to {
    -webkit-animation-timing-function: cubic-bezier(0.215, 0.610, 0.355, 1.000);
    animation-timing-function: cubic-bezier(0.215, 0.610, 0.355, 1.000);
  }

  0% {
    opacity: 0;
    -webkit-transform: scale3d(.3, .3, .3);
    transform: scale3d(.3, .3, .3);
  }

  20% {
    -webkit-transform: scale3d(1.1, 1.1, 1.1);
    transform: scale3d(1.1, 1.1, 1.1);
  }

  40% {
    -webkit-transform: scale3d(.9, .9, .9);
    transform: scale3d(.9, .9, .9);
  }

  60% {
    opacity: 1;
    -webkit-transform: scale3d(1.03, 1.03, 1.03);
    transform: scale3d(1.03, 1.03, 1.03);
  }

  80% {
    -webkit-transform: scale3d(.97, .97, .97);
    transform: scale3d(.97, .97, .97);
  }

  to {
    opacity: 1;
    -webkit-transform: scale3d(1, 1, 1);
    transform: scale3d(1, 1, 1);
  }
}

.bounceIn {
  -webkit-animation-name: bounceIn;
  animation-name: bounceIn;
}

@-webkit-keyframes bounceInDown {

  from,
  60%,
  75%,
  90%,
  to {
    -webkit-animation-timing-function: cubic-bezier(0.215, 0.610, 0.355, 1.000);
    animation-timing-function: cubic-bezier(0.215, 0.610, 0.355, 1.000);
  }

  0% {
    opacity: 0;
    -webkit-transform: translate3d(0, -3000px, 0);
    transform: translate3d(0, -3000px, 0);
  }

  60% {
    opacity: 1;
    -webkit-transform: translate3d(0, 25px, 0);
    transform: translate3d(0, 25px, 0);
  }

  75% {
    -webkit-transform: translate3d(0, -10px, 0);
    transform: translate3d(0, -10px, 0);
  }

  90% {
    -webkit-transform: translate3d(0, 5px, 0);
    transform: translate3d(0, 5px, 0);
  }

  to {
    -webkit-transform: none;
    transform: none;
  }
}

@keyframes bounceInDown {

  from,
  60%,
  75%,
  90%,
  to {
    -webkit-animation-timing-function: cubic-bezier(0.215, 0.610, 0.355, 1.000);
    animation-timing-function: cubic-bezier(0.215, 0.610, 0.355, 1.000);
  }

  0% {
    opacity: 0;
    -webkit-transform: translate3d(0, -3000px, 0);
    transform: translate3d(0, -3000px, 0);
  }

  60% {
    opacity: 1;
    -webkit-transform: translate3d(0, 25px, 0);
    transform: translate3d(0, 25px, 0);
  }

  75% {
    -webkit-transform: translate3d(0, -10px, 0);
    transform: translate3d(0, -10px, 0);
  }

  90% {
    -webkit-transform: translate3d(0, 5px, 0);
    transform: translate3d(0, 5px, 0);
  }

  to {
    -webkit-transform: none;
    transform: none;
  }
}

.bounceInDown {
  -webkit-animation-name: bounceInDown;
  animation-name: bounceInDown;
}

@-webkit-keyframes bounceInLeft {

  from,
  60%,
  75%,
  90%,
  to {
    -webkit-animation-timing-function: cubic-bezier(0.215, 0.610, 0.355, 1.000);
    animation-timing-function: cubic-bezier(0.215, 0.610, 0.355, 1.000);
  }

  0% {
    opacity: 0;
    -webkit-transform: translate3d(-3000px, 0, 0);
    transform: translate3d(-3000px, 0, 0);
  }

  60% {
    opacity: 1;
    -webkit-transform: translate3d(25px, 0, 0);
    transform: translate3d(25px, 0, 0);
  }

  75% {
    -webkit-transform: translate3d(-10px, 0, 0);
    transform: translate3d(-10px, 0, 0);
  }

  90% {
    -webkit-transform: translate3d(5px, 0, 0);
    transform: translate3d(5px, 0, 0);
  }

  to {
    -webkit-transform: none;
    transform: none;
  }
}

@keyframes bounceInLeft {

  from,
  60%,
  75%,
  90%,
  to {
    -webkit-animation-timing-function: cubic-bezier(0.215, 0.610, 0.355, 1.000);
    animation-timing-function: cubic-bezier(0.215, 0.610, 0.355, 1.000);
  }

  0% {
    opacity: 0;
    -webkit-transform: translate3d(-3000px, 0, 0);
    transform: translate3d(-3000px, 0, 0);
  }

  60% {
    opacity: 1;
    -webkit-transform: translate3d(25px, 0, 0);
    transform: translate3d(25px, 0, 0);
  }

  75% {
    -webkit-transform: translate3d(-10px, 0, 0);
    transform: translate3d(-10px, 0, 0);
  }

  90% {
    -webkit-transform: translate3d(5px, 0, 0);
    transform: translate3d(5px, 0, 0);
  }

  to {
    -webkit-transform: none;
    transform: none;
  }
}

.bounceInLeft {
  -webkit-animation-name: bounceInLeft;
  animation-name: bounceInLeft;
}

@-webkit-keyframes bounceInRight {

  from,
  60%,
  75%,
  90%,
  to {
    -webkit-animation-timing-function: cubic-bezier(0.215, 0.610, 0.355, 1.000);
    animation-timing-function: cubic-bezier(0.215, 0.610, 0.355, 1.000);
  }

  from {
    opacity: 0;
    -webkit-transform: translate3d(3000px, 0, 0);
    transform: translate3d(3000px, 0, 0);
  }

  60% {
    opacity: 1;
    -webkit-transform: translate3d(-25px, 0, 0);
    transform: translate3d(-25px, 0, 0);
  }

  75% {
    -webkit-transform: translate3d(10px, 0, 0);
    transform: translate3d(10px, 0, 0);
  }

  90% {
    -webkit-transform: translate3d(-5px, 0, 0);
    transform: translate3d(-5px, 0, 0);
  }

  to {
    -webkit-transform: none;
    transform: none;
  }
}

@keyframes bounceInRight {

  from,
  60%,
  75%,
  90%,
  to {
    -webkit-animation-timing-function: cubic-bezier(0.215, 0.610, 0.355, 1.000);
    animation-timing-function: cubic-bezier(0.215, 0.610, 0.355, 1.000);
  }

  from {
    opacity: 0;
    -webkit-transform: translate3d(3000px, 0, 0);
    transform: translate3d(3000px, 0, 0);
  }

  60% {
    opacity: 1;
    -webkit-transform: translate3d(-25px, 0, 0);
    transform: translate3d(-25px, 0, 0);
  }

  75% {
    -webkit-transform: translate3d(10px, 0, 0);
    transform: translate3d(10px, 0, 0);
  }

  90% {
    -webkit-transform: translate3d(-5px, 0, 0);
    transform: translate3d(-5px, 0, 0);
  }

  to {
    -webkit-transform: none;
    transform: none;
  }
}

.bounceInRight {
  -webkit-animation-name: bounceInRight;
  animation-name: bounceInRight;
}

@-webkit-keyframes bounceInUp {

  from,
  60%,
  75%,
  90%,
  to {
    -webkit-animation-timing-function: cubic-bezier(0.215, 0.610, 0.355, 1.000);
    animation-timing-function: cubic-bezier(0.215, 0.610, 0.355, 1.000);
  }

  from {
    opacity: 0;
    -webkit-transform: translate3d(0, 3000px, 0);
    transform: translate3d(0, 3000px, 0);
  }

  60% {
    opacity: 1;
    -webkit-transform: translate3d(0, -20px, 0);
    transform: translate3d(0, -20px, 0);
  }

  75% {
    -webkit-transform: translate3d(0, 10px, 0);
    transform: translate3d(0, 10px, 0);
  }

  90% {
    -webkit-transform: translate3d(0, -5px, 0);
    transform: translate3d(0, -5px, 0);
  }

  to {
    -webkit-transform: translate3d(0, 0, 0);
    transform: translate3d(0, 0, 0);
  }
}

@keyframes bounceInUp {

  from,
  60%,
  75%,
  90%,
  to {
    -webkit-animation-timing-function: cubic-bezier(0.215, 0.610, 0.355, 1.000);
    animation-timing-function: cubic-bezier(0.215, 0.610, 0.355, 1.000);
  }

  from {
    opacity: 0;
    -webkit-transform: translate3d(0, 3000px, 0);
    transform: translate3d(0, 3000px, 0);
  }

  60% {
    opacity: 1;
    -webkit-transform: translate3d(0, -20px, 0);
    transform: translate3d(0, -20px, 0);
  }

  75% {
    -webkit-transform: translate3d(0, 10px, 0);
    transform: translate3d(0, 10px, 0);
  }

  90% {
    -webkit-transform: translate3d(0, -5px, 0);
    transform: translate3d(0, -5px, 0);
  }

  to {
    -webkit-transform: translate3d(0, 0, 0);
    transform: translate3d(0, 0, 0);
  }
}

.bounceInUp {
  -webkit-animation-name: bounceInUp;
  animation-name: bounceInUp;
}

@-webkit-keyframes bounceOut {
  20% {
    -webkit-transform: scale3d(.9, .9, .9);
    transform: scale3d(.9, .9, .9);
  }

  50%,
  55% {
    opacity: 1;
    -webkit-transform: scale3d(1.1, 1.1, 1.1);
    transform: scale3d(1.1, 1.1, 1.1);
  }

  to {
    opacity: 0;
    -webkit-transform: scale3d(.3, .3, .3);
    transform: scale3d(.3, .3, .3);
  }
}

@keyframes bounceOut {
  20% {
    -webkit-transform: scale3d(.9, .9, .9);
    transform: scale3d(.9, .9, .9);
  }

  50%,
  55% {
    opacity: 1;
    -webkit-transform: scale3d(1.1, 1.1, 1.1);
    transform: scale3d(1.1, 1.1, 1.1);
  }

  to {
    opacity: 0;
    -webkit-transform: scale3d(.3, .3, .3);
    transform: scale3d(.3, .3, .3);
  }
}

.bounceOut {
  -webkit-animation-name: bounceOut;
  animation-name: bounceOut;
}

@-webkit-keyframes bounceOutDown {
  20% {
    -webkit-transform: translate3d(0, 10px, 0);
    transform: translate3d(0, 10px, 0);
  }

  40%,
  45% {
    opacity: 1;
    -webkit-transform: translate3d(0, -20px, 0);
    transform: translate3d(0, -20px, 0);
  }

  to {
    opacity: 0;
    -webkit-transform: translate3d(0, 2000px, 0);
    transform: translate3d(0, 2000px, 0);
  }
}

@keyframes bounceOutDown {
  20% {
    -webkit-transform: translate3d(0, 10px, 0);
    transform: translate3d(0, 10px, 0);
  }

  40%,
  45% {
    opacity: 1;
    -webkit-transform: translate3d(0, -20px, 0);
    transform: translate3d(0, -20px, 0);
  }

  to {
    opacity: 0;
    -webkit-transform: translate3d(0, 2000px, 0);
    transform: translate3d(0, 2000px, 0);
  }
}

.bounceOutDown {
  -webkit-animation-name: bounceOutDown;
  animation-name: bounceOutDown;
}

@-webkit-keyframes bounceOutLeft {
  20% {
    opacity: 1;
    -webkit-transform: translate3d(20px, 0, 0);
    transform: translate3d(20px, 0, 0);
  }

  to {
    opacity: 0;
    -webkit-transform: translate3d(-2000px, 0, 0);
    transform: translate3d(-2000px, 0, 0);
  }
}

@keyframes bounceOutLeft {
  20% {
    opacity: 1;
    -webkit-transform: translate3d(20px, 0, 0);
    transform: translate3d(20px, 0, 0);
  }

  to {
    opacity: 0;
    -webkit-transform: translate3d(-2000px, 0, 0);
    transform: translate3d(-2000px, 0, 0);
  }
}

.bounceOutLeft {
  -webkit-animation-name: bounceOutLeft;
  animation-name: bounceOutLeft;
}

@-webkit-keyframes bounceOutRight {
  20% {
    opacity: 1;
    -webkit-transform: translate3d(-20px, 0, 0);
    transform: translate3d(-20px, 0, 0);
  }

  to {
    opacity: 0;
    -webkit-transform: translate3d(2000px, 0, 0);
    transform: translate3d(2000px, 0, 0);
  }
}

@keyframes bounceOutRight {
  20% {
    opacity: 1;
    -webkit-transform: translate3d(-20px, 0, 0);
    transform: translate3d(-20px, 0, 0);
  }

  to {
    opacity: 0;
    -webkit-transform: translate3d(2000px, 0, 0);
    transform: translate3d(2000px, 0, 0);
  }
}

.bounceOutRight {
  -webkit-animation-name: bounceOutRight;
  animation-name: bounceOutRight;
}

@-webkit-keyframes bounceOutUp {
  20% {
    -webkit-transform: translate3d(0, -10px, 0);
    transform: translate3d(0, -10px, 0);
  }

  40%,
  45% {
    opacity: 1;
    -webkit-transform: translate3d(0, 20px, 0);
    transform: translate3d(0, 20px, 0);
  }

  to {
    opacity: 0;
    -webkit-transform: translate3d(0, -2000px, 0);
    transform: translate3d(0, -2000px, 0);
  }
}

@keyframes bounceOutUp {
  20% {
    -webkit-transform: translate3d(0, -10px, 0);
    transform: translate3d(0, -10px, 0);
  }

  40%,
  45% {
    opacity: 1;
    -webkit-transform: translate3d(0, 20px, 0);
    transform: translate3d(0, 20px, 0);
  }

  to {
    opacity: 0;
    -webkit-transform: translate3d(0, -2000px, 0);
    transform: translate3d(0, -2000px, 0);
  }
}

.bounceOutUp {
  -webkit-animation-name: bounceOutUp;
  animation-name: bounceOutUp;
}

@-webkit-keyframes fadeIn {
  from {
    opacity: 0;
  }

  to {
    opacity: 1;
  }
}

@keyframes fadeIn {
  from {
    opacity: 0;
  }

  to {
    opacity: 1;
  }
}

.fadeIn {
  -webkit-animation-name: fadeIn;
  animation-name: fadeIn;
}

@-webkit-keyframes fadeInDown {
  from {
    opacity: 0;
    -webkit-transform: translate3d(0, -100%, 0);
    transform: translate3d(0, -100%, 0);
  }

  to {
    opacity: 1;
    -webkit-transform: none;
    transform: none;
  }
}

@keyframes fadeInDown {
  from {
    opacity: 0;
    -webkit-transform: translate3d(0, -100%, 0);
    transform: translate3d(0, -100%, 0);
  }

  to {
    opacity: 1;
    -webkit-transform: none;
    transform: none;
  }
}

.fadeInDown {
  -webkit-animation-name: fadeInDown;
  animation-name: fadeInDown;
}

@-webkit-keyframes fadeInDownBig {
  from {
    opacity: 0;
    -webkit-transform: translate3d(0, -2000px, 0);
    transform: translate3d(0, -2000px, 0);
  }

  to {
    opacity: 1;
    -webkit-transform: none;
    transform: none;
  }
}

@keyframes fadeInDownBig {
  from {
    opacity: 0;
    -webkit-transform: translate3d(0, -2000px, 0);
    transform: translate3d(0, -2000px, 0);
  }

  to {
    opacity: 1;
    -webkit-transform: none;
    transform: none;
  }
}

.fadeInDownBig {
  -webkit-animation-name: fadeInDownBig;
  animation-name: fadeInDownBig;
}

@-webkit-keyframes fadeInLeft {
  from {
    opacity: 0;
    -webkit-transform: translate3d(-100%, 0, 0);
    transform: translate3d(-100%, 0, 0);
  }

  to {
    opacity: 1;
    -webkit-transform: none;
    transform: none;
  }
}

@keyframes fadeInLeft {
  from {
    opacity: 0;
    -webkit-transform: translate3d(-100%, 0, 0);
    transform: translate3d(-100%, 0, 0);
  }

  to {
    opacity: 1;
    -webkit-transform: none;
    transform: none;
  }
}

.fadeInLeft {
  -webkit-animation-name: fadeInLeft;
  animation-name: fadeInLeft;
}

@-webkit-keyframes fadeInLeftBig {
  from {
    opacity: 0;
    -webkit-transform: translate3d(-2000px, 0, 0);
    transform: translate3d(-2000px, 0, 0);
  }

  to {
    opacity: 1;
    -webkit-transform: none;
    transform: none;
  }
}

@keyframes fadeInLeftBig {
  from {
    opacity: 0;
    -webkit-transform: translate3d(-2000px, 0, 0);
    transform: translate3d(-2000px, 0, 0);
  }

  to {
    opacity: 1;
    -webkit-transform: none;
    transform: none;
  }
}

.fadeInLeftBig {
  -webkit-animation-name: fadeInLeftBig;
  animation-name: fadeInLeftBig;
}

@-webkit-keyframes fadeInRight {
  from {
    opacity: 0;
    -webkit-transform: translate3d(100%, 0, 0);
    transform: translate3d(100%, 0, 0);
  }

  to {
    opacity: 1;
    -webkit-transform: none;
    transform: none;
  }
}

@keyframes fadeInRight {
  from {
    opacity: 0;
    -webkit-transform: translate3d(100%, 0, 0);
    transform: translate3d(100%, 0, 0);
  }

  to {
    opacity: 1;
    -webkit-transform: none;
    transform: none;
  }
}

.fadeInRight {
  -webkit-animation-name: fadeInRight;
  animation-name: fadeInRight;
}

@-webkit-keyframes fadeInRightBig {
  from {
    opacity: 0;
    -webkit-transform: translate3d(2000px, 0, 0);
    transform: translate3d(2000px, 0, 0);
  }

  to {
    opacity: 1;
    -webkit-transform: none;
    transform: none;
  }
}

@keyframes fadeInRightBig {
  from {
    opacity: 0;
    -webkit-transform: translate3d(2000px, 0, 0);
    transform: translate3d(2000px, 0, 0);
  }

  to {
    opacity: 1;
    -webkit-transform: none;
    transform: none;
  }
}

.fadeInRightBig {
  -webkit-animation-name: fadeInRightBig;
  animation-name: fadeInRightBig;
}

@-webkit-keyframes fadeInUp {
  from {
    opacity: 0;
    -webkit-transform: translate3d(0, 100%, 0);
    transform: translate3d(0, 100%, 0);
  }

  to {
    opacity: 1;
    -webkit-transform: none;
    transform: none;
  }
}

@keyframes fadeInUp {
  from {
    opacity: 0;
    -webkit-transform: translate3d(0, 100%, 0);
    transform: translate3d(0, 100%, 0);
  }

  to {
    opacity: 1;
    -webkit-transform: none;
    transform: none;
  }
}

.fadeInUp {
  -webkit-animation-name: fadeInUp;
  animation-name: fadeInUp;
}

@-webkit-keyframes fadeInUpBig {
  from {
    opacity: 0;
    -webkit-transform: translate3d(0, 2000px, 0);
    transform: translate3d(0, 2000px, 0);
  }

  to {
    opacity: 1;
    -webkit-transform: none;
    transform: none;
  }
}

@keyframes fadeInUpBig {
  from {
    opacity: 0;
    -webkit-transform: translate3d(0, 2000px, 0);
    transform: translate3d(0, 2000px, 0);
  }

  to {
    opacity: 1;
    -webkit-transform: none;
    transform: none;
  }
}

.fadeInUpBig {
  -webkit-animation-name: fadeInUpBig;
  animation-name: fadeInUpBig;
}

@-webkit-keyframes fadeOut {
  from {
    opacity: 1;
  }

  to {
    opacity: 0;
  }
}

@keyframes fadeOut {
  from {
    opacity: 1;
  }

  to {
    opacity: 0;
  }
}

.fadeOut {
  -webkit-animation-name: fadeOut;
  animation-name: fadeOut;
}

@-webkit-keyframes fadeOutDown {
  from {
    opacity: 1;
  }

  to {
    opacity: 0;
    -webkit-transform: translate3d(0, 100%, 0);
    transform: translate3d(0, 100%, 0);
  }
}

@keyframes fadeOutDown {
  from {
    opacity: 1;
  }

  to {
    opacity: 0;
    -webkit-transform: translate3d(0, 100%, 0);
    transform: translate3d(0, 100%, 0);
  }
}

.fadeOutDown {
  -webkit-animation-name: fadeOutDown;
  animation-name: fadeOutDown;
}

@-webkit-keyframes fadeOutDownBig {
  from {
    opacity: 1;
  }

  to {
    opacity: 0;
    -webkit-transform: translate3d(0, 2000px, 0);
    transform: translate3d(0, 2000px, 0);
  }
}

@keyframes fadeOutDownBig {
  from {
    opacity: 1;
  }

  to {
    opacity: 0;
    -webkit-transform: translate3d(0, 2000px, 0);
    transform: translate3d(0, 2000px, 0);
  }
}

.fadeOutDownBig {
  -webkit-animation-name: fadeOutDownBig;
  animation-name: fadeOutDownBig;
}

@-webkit-keyframes fadeOutLeft {
  from {
    opacity: 1;
  }

  to {
    opacity: 0;
    -webkit-transform: translate3d(-100%, 0, 0);
    transform: translate3d(-100%, 0, 0);
  }
}

@keyframes fadeOutLeft {
  from {
    opacity: 1;
  }

  to {
    opacity: 0;
    -webkit-transform: translate3d(-100%, 0, 0);
    transform: translate3d(-100%, 0, 0);
  }
}

.fadeOutLeft {
  -webkit-animation-name: fadeOutLeft;
  animation-name: fadeOutLeft;
}

@-webkit-keyframes fadeOutLeftBig {
  from {
    opacity: 1;
  }

  to {
    opacity: 0;
    -webkit-transform: translate3d(-2000px, 0, 0);
    transform: translate3d(-2000px, 0, 0);
  }
}

@keyframes fadeOutLeftBig {
  from {
    opacity: 1;
  }

  to {
    opacity: 0;
    -webkit-transform: translate3d(-2000px, 0, 0);
    transform: translate3d(-2000px, 0, 0);
  }
}

.fadeOutLeftBig {
  -webkit-animation-name: fadeOutLeftBig;
  animation-name: fadeOutLeftBig;
}

@-webkit-keyframes fadeOutRight {
  from {
    opacity: 1;
  }

  to {
    opacity: 0;
    -webkit-transform: translate3d(100%, 0, 0);
    transform: translate3d(100%, 0, 0);
  }
}

@keyframes fadeOutRight {
  from {
    opacity: 1;
  }

  to {
    opacity: 0;
    -webkit-transform: translate3d(100%, 0, 0);
    transform: translate3d(100%, 0, 0);
  }
}

.fadeOutRight {
  -webkit-animation-name: fadeOutRight;
  animation-name: fadeOutRight;
}

@-webkit-keyframes fadeOutRightBig {
  from {
    opacity: 1;
  }

  to {
    opacity: 0;
    -webkit-transform: translate3d(2000px, 0, 0);
    transform: translate3d(2000px, 0, 0);
  }
}

@keyframes fadeOutRightBig {
  from {
    opacity: 1;
  }

  to {
    opacity: 0;
    -webkit-transform: translate3d(2000px, 0, 0);
    transform: translate3d(2000px, 0, 0);
  }
}

.fadeOutRightBig {
  -webkit-animation-name: fadeOutRightBig;
  animation-name: fadeOutRightBig;
}

@-webkit-keyframes fadeOutUp {
  from {
    opacity: 1;
  }

  to {
    opacity: 0;
    -webkit-transform: translate3d(0, -100%, 0);
    transform: translate3d(0, -100%, 0);
  }
}

@keyframes fadeOutUp {
  from {
    opacity: 1;
  }

  to {
    opacity: 0;
    -webkit-transform: translate3d(0, -100%, 0);
    transform: translate3d(0, -100%, 0);
  }
}

.fadeOutUp {
  -webkit-animation-name: fadeOutUp;
  animation-name: fadeOutUp;
}

@-webkit-keyframes fadeOutUpBig {
  from {
    opacity: 1;
  }

  to {
    opacity: 0;
    -webkit-transform: translate3d(0, -2000px, 0);
    transform: translate3d(0, -2000px, 0);
  }
}

@keyframes fadeOutUpBig {
  from {
    opacity: 1;
  }

  to {
    opacity: 0;
    -webkit-transform: translate3d(0, -2000px, 0);
    transform: translate3d(0, -2000px, 0);
  }
}

.fadeOutUpBig {
  -webkit-animation-name: fadeOutUpBig;
  animation-name: fadeOutUpBig;
}

@-webkit-keyframes flip {
  from {
    -webkit-transform: perspective(400px) rotate3d(0, 1, 0, -360deg);
    transform: perspective(400px) rotate3d(0, 1, 0, -360deg);
    -webkit-animation-timing-function: ease-out;
    animation-timing-function: ease-out;
  }

  40% {
    -webkit-transform: perspective(400px) translate3d(0, 0, 150px) rotate3d(0, 1, 0, -190deg);
    transform: perspective(400px) translate3d(0, 0, 150px) rotate3d(0, 1, 0, -190deg);
    -webkit-animation-timing-function: ease-out;
    animation-timing-function: ease-out;
  }

  50% {
    -webkit-transform: perspective(400px) translate3d(0, 0, 150px) rotate3d(0, 1, 0, -170deg);
    transform: perspective(400px) translate3d(0, 0, 150px) rotate3d(0, 1, 0, -170deg);
    -webkit-animation-timing-function: ease-in;
    animation-timing-function: ease-in;
  }

  80% {
    -webkit-transform: perspective(400px) scale3d(.95, .95, .95);
    transform: perspective(400px) scale3d(.95, .95, .95);
    -webkit-animation-timing-function: ease-in;
    animation-timing-function: ease-in;
  }

  to {
    -webkit-transform: perspective(400px);
    transform: perspective(400px);
    -webkit-animation-timing-function: ease-in;
    animation-timing-function: ease-in;
  }
}

@keyframes flip {
  from {
    -webkit-transform: perspective(400px) rotate3d(0, 1, 0, -360deg);
    transform: perspective(400px) rotate3d(0, 1, 0, -360deg);
    -webkit-animation-timing-function: ease-out;
    animation-timing-function: ease-out;
  }

  40% {
    -webkit-transform: perspective(400px) translate3d(0, 0, 150px) rotate3d(0, 1, 0, -190deg);
    transform: perspective(400px) translate3d(0, 0, 150px) rotate3d(0, 1, 0, -190deg);
    -webkit-animation-timing-function: ease-out;
    animation-timing-function: ease-out;
  }

  50% {
    -webkit-transform: perspective(400px) translate3d(0, 0, 150px) rotate3d(0, 1, 0, -170deg);
    transform: perspective(400px) translate3d(0, 0, 150px) rotate3d(0, 1, 0, -170deg);
    -webkit-animation-timing-function: ease-in;
    animation-timing-function: ease-in;
  }

  80% {
    -webkit-transform: perspective(400px) scale3d(.95, .95, .95);
    transform: perspective(400px) scale3d(.95, .95, .95);
    -webkit-animation-timing-function: ease-in;
    animation-timing-function: ease-in;
  }

  to {
    -webkit-transform: perspective(400px);
    transform: perspective(400px);
    -webkit-animation-timing-function: ease-in;
    animation-timing-function: ease-in;
  }
}

.animated.flip {
  -webkit-backface-visibility: visible;
  backface-visibility: visible;
  -webkit-animation-name: flip;
  animation-name: flip;
}

@-webkit-keyframes flipInX {
  from {
    -webkit-transform: perspective(400px) rotate3d(1, 0, 0, 90deg);
    transform: perspective(400px) rotate3d(1, 0, 0, 90deg);
    -webkit-animation-timing-function: ease-in;
    animation-timing-function: ease-in;
    opacity: 0;
  }

  40% {
    -webkit-transform: perspective(400px) rotate3d(1, 0, 0, -20deg);
    transform: perspective(400px) rotate3d(1, 0, 0, -20deg);
    -webkit-animation-timing-function: ease-in;
    animation-timing-function: ease-in;
  }

  60% {
    -webkit-transform: perspective(400px) rotate3d(1, 0, 0, 10deg);
    transform: perspective(400px) rotate3d(1, 0, 0, 10deg);
    opacity: 1;
  }

  80% {
    -webkit-transform: perspective(400px) rotate3d(1, 0, 0, -5deg);
    transform: perspective(400px) rotate3d(1, 0, 0, -5deg);
  }

  to {
    -webkit-transform: perspective(400px);
    transform: perspective(400px);
  }
}

@keyframes flipInX {
  from {
    -webkit-transform: perspective(400px) rotate3d(1, 0, 0, 90deg);
    transform: perspective(400px) rotate3d(1, 0, 0, 90deg);
    -webkit-animation-timing-function: ease-in;
    animation-timing-function: ease-in;
    opacity: 0;
  }

  40% {
    -webkit-transform: perspective(400px) rotate3d(1, 0, 0, -20deg);
    transform: perspective(400px) rotate3d(1, 0, 0, -20deg);
    -webkit-animation-timing-function: ease-in;
    animation-timing-function: ease-in;
  }

  60% {
    -webkit-transform: perspective(400px) rotate3d(1, 0, 0, 10deg);
    transform: perspective(400px) rotate3d(1, 0, 0, 10deg);
    opacity: 1;
  }

  80% {
    -webkit-transform: perspective(400px) rotate3d(1, 0, 0, -5deg);
    transform: perspective(400px) rotate3d(1, 0, 0, -5deg);
  }

  to {
    -webkit-transform: perspective(400px);
    transform: perspective(400px);
  }
}

.flipInX {
  -webkit-backface-visibility: visible !important;
  backface-visibility: visible !important;
  -webkit-animation-name: flipInX;
  animation-name: flipInX;
}

@-webkit-keyframes flipInY {
  from {
    -webkit-transform: perspective(400px) rotate3d(0, 1, 0, 90deg);
    transform: perspective(400px) rotate3d(0, 1, 0, 90deg);
    -webkit-animation-timing-function: ease-in;
    animation-timing-function: ease-in;
    opacity: 0;
  }

  40% {
    -webkit-transform: perspective(400px) rotate3d(0, 1, 0, -20deg);
    transform: perspective(400px) rotate3d(0, 1, 0, -20deg);
    -webkit-animation-timing-function: ease-in;
    animation-timing-function: ease-in;
  }

  60% {
    -webkit-transform: perspective(400px) rotate3d(0, 1, 0, 10deg);
    transform: perspective(400px) rotate3d(0, 1, 0, 10deg);
    opacity: 1;
  }

  80% {
    -webkit-transform: perspective(400px) rotate3d(0, 1, 0, -5deg);
    transform: perspective(400px) rotate3d(0, 1, 0, -5deg);
  }

  to {
    -webkit-transform: perspective(400px);
    transform: perspective(400px);
  }
}

@keyframes flipInY {
  from {
    -webkit-transform: perspective(400px) rotate3d(0, 1, 0, 90deg);
    transform: perspective(400px) rotate3d(0, 1, 0, 90deg);
    -webkit-animation-timing-function: ease-in;
    animation-timing-function: ease-in;
    opacity: 0;
  }

  40% {
    -webkit-transform: perspective(400px) rotate3d(0, 1, 0, -20deg);
    transform: perspective(400px) rotate3d(0, 1, 0, -20deg);
    -webkit-animation-timing-function: ease-in;
    animation-timing-function: ease-in;
  }

  60% {
    -webkit-transform: perspective(400px) rotate3d(0, 1, 0, 10deg);
    transform: perspective(400px) rotate3d(0, 1, 0, 10deg);
    opacity: 1;
  }

  80% {
    -webkit-transform: perspective(400px) rotate3d(0, 1, 0, -5deg);
    transform: perspective(400px) rotate3d(0, 1, 0, -5deg);
  }

  to {
    -webkit-transform: perspective(400px);
    transform: perspective(400px);
  }
}

.flipInY {
  -webkit-backface-visibility: visible !important;
  backface-visibility: visible !important;
  -webkit-animation-name: flipInY;
  animation-name: flipInY;
}

@-webkit-keyframes flipOutX {
  from {
    -webkit-transform: perspective(400px);
    transform: perspective(400px);
  }

  30% {
    -webkit-transform: perspective(400px) rotate3d(1, 0, 0, -20deg);
    transform: perspective(400px) rotate3d(1, 0, 0, -20deg);
    opacity: 1;
  }

  to {
    -webkit-transform: perspective(400px) rotate3d(1, 0, 0, 90deg);
    transform: perspective(400px) rotate3d(1, 0, 0, 90deg);
    opacity: 0;
  }
}

@keyframes flipOutX {
  from {
    -webkit-transform: perspective(400px);
    transform: perspective(400px);
  }

  30% {
    -webkit-transform: perspective(400px) rotate3d(1, 0, 0, -20deg);
    transform: perspective(400px) rotate3d(1, 0, 0, -20deg);
    opacity: 1;
  }

  to {
    -webkit-transform: perspective(400px) rotate3d(1, 0, 0, 90deg);
    transform: perspective(400px) rotate3d(1, 0, 0, 90deg);
    opacity: 0;
  }
}

.flipOutX {
  -webkit-animation-name: flipOutX;
  animation-name: flipOutX;
  -webkit-backface-visibility: visible !important;
  backface-visibility: visible !important;
}

@-webkit-keyframes flipOutY {
  from {
    -webkit-transform: perspective(400px);
    transform: perspective(400px);
  }

  30% {
    -webkit-transform: perspective(400px) rotate3d(0, 1, 0, -15deg);
    transform: perspective(400px) rotate3d(0, 1, 0, -15deg);
    opacity: 1;
  }

  to {
    -webkit-transform: perspective(400px) rotate3d(0, 1, 0, 90deg);
    transform: perspective(400px) rotate3d(0, 1, 0, 90deg);
    opacity: 0;
  }
}

@keyframes flipOutY {
  from {
    -webkit-transform: perspective(400px);
    transform: perspective(400px);
  }

  30% {
    -webkit-transform: perspective(400px) rotate3d(0, 1, 0, -15deg);
    transform: perspective(400px) rotate3d(0, 1, 0, -15deg);
    opacity: 1;
  }

  to {
    -webkit-transform: perspective(400px) rotate3d(0, 1, 0, 90deg);
    transform: perspective(400px) rotate3d(0, 1, 0, 90deg);
    opacity: 0;
  }
}

.flipOutY {
  -webkit-backface-visibility: visible !important;
  backface-visibility: visible !important;
  -webkit-animation-name: flipOutY;
  animation-name: flipOutY;
}

@-webkit-keyframes lightSpeedIn {
  from {
    -webkit-transform: translate3d(100%, 0, 0) skewX(-30deg);
    transform: translate3d(100%, 0, 0) skewX(-30deg);
    opacity: 0;
  }

  60% {
    -webkit-transform: skewX(20deg);
    transform: skewX(20deg);
    opacity: 1;
  }

  80% {
    -webkit-transform: skewX(-5deg);
    transform: skewX(-5deg);
    opacity: 1;
  }

  to {
    -webkit-transform: none;
    transform: none;
    opacity: 1;
  }
}

@keyframes lightSpeedIn {
  from {
    -webkit-transform: translate3d(100%, 0, 0) skewX(-30deg);
    transform: translate3d(100%, 0, 0) skewX(-30deg);
    opacity: 0;
  }

  60% {
    -webkit-transform: skewX(20deg);
    transform: skewX(20deg);
    opacity: 1;
  }

  80% {
    -webkit-transform: skewX(-5deg);
    transform: skewX(-5deg);
    opacity: 1;
  }

  to {
    -webkit-transform: none;
    transform: none;
    opacity: 1;
  }
}

.lightSpeedIn {
  -webkit-animation-name: lightSpeedIn;
  animation-name: lightSpeedIn;
  -webkit-animation-timing-function: ease-out;
  animation-timing-function: ease-out;
}

@-webkit-keyframes lightSpeedOut {
  from {
    opacity: 1;
  }

  to {
    -webkit-transform: translate3d(100%, 0, 0) skewX(30deg);
    transform: translate3d(100%, 0, 0) skewX(30deg);
    opacity: 0;
  }
}

@keyframes lightSpeedOut {
  from {
    opacity: 1;
  }

  to {
    -webkit-transform: translate3d(100%, 0, 0) skewX(30deg);
    transform: translate3d(100%, 0, 0) skewX(30deg);
    opacity: 0;
  }
}

.lightSpeedOut {
  -webkit-animation-name: lightSpeedOut;
  animation-name: lightSpeedOut;
  -webkit-animation-timing-function: ease-in;
  animation-timing-function: ease-in;
}

@-webkit-keyframes rotateIn {
  from {
    -webkit-transform-origin: center;
    transform-origin: center;
    -webkit-transform: rotate3d(0, 0, 1, -200deg);
    transform: rotate3d(0, 0, 1, -200deg);
    opacity: 0;
  }

  to {
    -webkit-transform-origin: center;
    transform-origin: center;
    -webkit-transform: none;
    transform: none;
    opacity: 1;
  }
}

@keyframes rotateIn {
  from {
    -webkit-transform-origin: center;
    transform-origin: center;
    -webkit-transform: rotate3d(0, 0, 1, -200deg);
    transform: rotate3d(0, 0, 1, -200deg);
    opacity: 0;
  }

  to {
    -webkit-transform-origin: center;
    transform-origin: center;
    -webkit-transform: none;
    transform: none;
    opacity: 1;
  }
}

.rotateIn {
  -webkit-animation-name: rotateIn;
  animation-name: rotateIn;
}

@-webkit-keyframes rotateInDownLeft {
  from {
    -webkit-transform-origin: left bottom;
    transform-origin: left bottom;
    -webkit-transform: rotate3d(0, 0, 1, -45deg);
    transform: rotate3d(0, 0, 1, -45deg);
    opacity: 0;
  }

  to {
    -webkit-transform-origin: left bottom;
    transform-origin: left bottom;
    -webkit-transform: none;
    transform: none;
    opacity: 1;
  }
}

@keyframes rotateInDownLeft {
  from {
    -webkit-transform-origin: left bottom;
    transform-origin: left bottom;
    -webkit-transform: rotate3d(0, 0, 1, -45deg);
    transform: rotate3d(0, 0, 1, -45deg);
    opacity: 0;
  }

  to {
    -webkit-transform-origin: left bottom;
    transform-origin: left bottom;
    -webkit-transform: none;
    transform: none;
    opacity: 1;
  }
}

.rotateInDownLeft {
  -webkit-animation-name: rotateInDownLeft;
  animation-name: rotateInDownLeft;
}

@-webkit-keyframes rotateInDownRight {
  from {
    -webkit-transform-origin: right bottom;
    transform-origin: right bottom;
    -webkit-transform: rotate3d(0, 0, 1, 45deg);
    transform: rotate3d(0, 0, 1, 45deg);
    opacity: 0;
  }

  to {
    -webkit-transform-origin: right bottom;
    transform-origin: right bottom;
    -webkit-transform: none;
    transform: none;
    opacity: 1;
  }
}

@keyframes rotateInDownRight {
  from {
    -webkit-transform-origin: right bottom;
    transform-origin: right bottom;
    -webkit-transform: rotate3d(0, 0, 1, 45deg);
    transform: rotate3d(0, 0, 1, 45deg);
    opacity: 0;
  }

  to {
    -webkit-transform-origin: right bottom;
    transform-origin: right bottom;
    -webkit-transform: none;
    transform: none;
    opacity: 1;
  }
}

.rotateInDownRight {
  -webkit-animation-name: rotateInDownRight;
  animation-name: rotateInDownRight;
}

@-webkit-keyframes rotateInUpLeft {
  from {
    -webkit-transform-origin: left bottom;
    transform-origin: left bottom;
    -webkit-transform: rotate3d(0, 0, 1, 45deg);
    transform: rotate3d(0, 0, 1, 45deg);
    opacity: 0;
  }

  to {
    -webkit-transform-origin: left bottom;
    transform-origin: left bottom;
    -webkit-transform: none;
    transform: none;
    opacity: 1;
  }
}

@keyframes rotateInUpLeft {
  from {
    -webkit-transform-origin: left bottom;
    transform-origin: left bottom;
    -webkit-transform: rotate3d(0, 0, 1, 45deg);
    transform: rotate3d(0, 0, 1, 45deg);
    opacity: 0;
  }

  to {
    -webkit-transform-origin: left bottom;
    transform-origin: left bottom;
    -webkit-transform: none;
    transform: none;
    opacity: 1;
  }
}

.rotateInUpLeft {
  -webkit-animation-name: rotateInUpLeft;
  animation-name: rotateInUpLeft;
}

@-webkit-keyframes rotateInUpRight {
  from {
    -webkit-transform-origin: right bottom;
    transform-origin: right bottom;
    -webkit-transform: rotate3d(0, 0, 1, -90deg);
    transform: rotate3d(0, 0, 1, -90deg);
    opacity: 0;
  }

  to {
    -webkit-transform-origin: right bottom;
    transform-origin: right bottom;
    -webkit-transform: none;
    transform: none;
    opacity: 1;
  }
}

@keyframes rotateInUpRight {
  from {
    -webkit-transform-origin: right bottom;
    transform-origin: right bottom;
    -webkit-transform: rotate3d(0, 0, 1, -90deg);
    transform: rotate3d(0, 0, 1, -90deg);
    opacity: 0;
  }

  to {
    -webkit-transform-origin: right bottom;
    transform-origin: right bottom;
    -webkit-transform: none;
    transform: none;
    opacity: 1;
  }
}

.rotateInUpRight {
  -webkit-animation-name: rotateInUpRight;
  animation-name: rotateInUpRight;
}

@-webkit-keyframes rotateOut {
  from {
    -webkit-transform-origin: center;
    transform-origin: center;
    opacity: 1;
  }

  to {
    -webkit-transform-origin: center;
    transform-origin: center;
    -webkit-transform: rotate3d(0, 0, 1, 200deg);
    transform: rotate3d(0, 0, 1, 200deg);
    opacity: 0;
  }
}

@keyframes rotateOut {
  from {
    -webkit-transform-origin: center;
    transform-origin: center;
    opacity: 1;
  }

  to {
    -webkit-transform-origin: center;
    transform-origin: center;
    -webkit-transform: rotate3d(0, 0, 1, 200deg);
    transform: rotate3d(0, 0, 1, 200deg);
    opacity: 0;
  }
}

.rotateOut {
  -webkit-animation-name: rotateOut;
  animation-name: rotateOut;
}

@-webkit-keyframes rotateOutDownLeft {
  from {
    -webkit-transform-origin: left bottom;
    transform-origin: left bottom;
    opacity: 1;
  }

  to {
    -webkit-transform-origin: left bottom;
    transform-origin: left bottom;
    -webkit-transform: rotate3d(0, 0, 1, 45deg);
    transform: rotate3d(0, 0, 1, 45deg);
    opacity: 0;
  }
}

@keyframes rotateOutDownLeft {
  from {
    -webkit-transform-origin: left bottom;
    transform-origin: left bottom;
    opacity: 1;
  }

  to {
    -webkit-transform-origin: left bottom;
    transform-origin: left bottom;
    -webkit-transform: rotate3d(0, 0, 1, 45deg);
    transform: rotate3d(0, 0, 1, 45deg);
    opacity: 0;
  }
}

.rotateOutDownLeft {
  -webkit-animation-name: rotateOutDownLeft;
  animation-name: rotateOutDownLeft;
}

@-webkit-keyframes rotateOutDownRight {
  from {
    -webkit-transform-origin: right bottom;
    transform-origin: right bottom;
    opacity: 1;
  }

  to {
    -webkit-transform-origin: right bottom;
    transform-origin: right bottom;
    -webkit-transform: rotate3d(0, 0, 1, -45deg);
    transform: rotate3d(0, 0, 1, -45deg);
    opacity: 0;
  }
}

@keyframes rotateOutDownRight {
  from {
    -webkit-transform-origin: right bottom;
    transform-origin: right bottom;
    opacity: 1;
  }

  to {
    -webkit-transform-origin: right bottom;
    transform-origin: right bottom;
    -webkit-transform: rotate3d(0, 0, 1, -45deg);
    transform: rotate3d(0, 0, 1, -45deg);
    opacity: 0;
  }
}

.rotateOutDownRight {
  -webkit-animation-name: rotateOutDownRight;
  animation-name: rotateOutDownRight;
}

@-webkit-keyframes rotateOutUpLeft {
  from {
    -webkit-transform-origin: left bottom;
    transform-origin: left bottom;
    opacity: 1;
  }

  to {
    -webkit-transform-origin: left bottom;
    transform-origin: left bottom;
    -webkit-transform: rotate3d(0, 0, 1, -45deg);
    transform: rotate3d(0, 0, 1, -45deg);
    opacity: 0;
  }
}

@keyframes rotateOutUpLeft {
  from {
    -webkit-transform-origin: left bottom;
    transform-origin: left bottom;
    opacity: 1;
  }

  to {
    -webkit-transform-origin: left bottom;
    transform-origin: left bottom;
    -webkit-transform: rotate3d(0, 0, 1, -45deg);
    transform: rotate3d(0, 0, 1, -45deg);
    opacity: 0;
  }
}

.rotateOutUpLeft {
  -webkit-animation-name: rotateOutUpLeft;
  animation-name: rotateOutUpLeft;
}

@-webkit-keyframes rotateOutUpRight {
  from {
    -webkit-transform-origin: right bottom;
    transform-origin: right bottom;
    opacity: 1;
  }

  to {
    -webkit-transform-origin: right bottom;
    transform-origin: right bottom;
    -webkit-transform: rotate3d(0, 0, 1, 90deg);
    transform: rotate3d(0, 0, 1, 90deg);
    opacity: 0;
  }
}

@keyframes rotateOutUpRight {
  from {
    -webkit-transform-origin: right bottom;
    transform-origin: right bottom;
    opacity: 1;
  }

  to {
    -webkit-transform-origin: right bottom;
    transform-origin: right bottom;
    -webkit-transform: rotate3d(0, 0, 1, 90deg);
    transform: rotate3d(0, 0, 1, 90deg);
    opacity: 0;
  }
}

.rotateOutUpRight {
  -webkit-animation-name: rotateOutUpRight;
  animation-name: rotateOutUpRight;
}

@-webkit-keyframes hinge {
  0% {
    -webkit-transform-origin: top left;
    transform-origin: top left;
    -webkit-animation-timing-function: ease-in-out;
    animation-timing-function: ease-in-out;
  }

  20%,
  60% {
    -webkit-transform: rotate3d(0, 0, 1, 80deg);
    transform: rotate3d(0, 0, 1, 80deg);
    -webkit-transform-origin: top left;
    transform-origin: top left;
    -webkit-animation-timing-function: ease-in-out;
    animation-timing-function: ease-in-out;
  }

  40%,
  80% {
    -webkit-transform: rotate3d(0, 0, 1, 60deg);
    transform: rotate3d(0, 0, 1, 60deg);
    -webkit-transform-origin: top left;
    transform-origin: top left;
    -webkit-animation-timing-function: ease-in-out;
    animation-timing-function: ease-in-out;
    opacity: 1;
  }

  to {
    -webkit-transform: translate3d(0, 700px, 0);
    transform: translate3d(0, 700px, 0);
    opacity: 0;
  }
}

@keyframes hinge {
  0% {
    -webkit-transform-origin: top left;
    transform-origin: top left;
    -webkit-animation-timing-function: ease-in-out;
    animation-timing-function: ease-in-out;
  }

  20%,
  60% {
    -webkit-transform: rotate3d(0, 0, 1, 80deg);
    transform: rotate3d(0, 0, 1, 80deg);
    -webkit-transform-origin: top left;
    transform-origin: top left;
    -webkit-animation-timing-function: ease-in-out;
    animation-timing-function: ease-in-out;
  }

  40%,
  80% {
    -webkit-transform: rotate3d(0, 0, 1, 60deg);
    transform: rotate3d(0, 0, 1, 60deg);
    -webkit-transform-origin: top left;
    transform-origin: top left;
    -webkit-animation-timing-function: ease-in-out;
    animation-timing-function: ease-in-out;
    opacity: 1;
  }

  to {
    -webkit-transform: translate3d(0, 700px, 0);
    transform: translate3d(0, 700px, 0);
    opacity: 0;
  }
}

.hinge {
  -webkit-animation-name: hinge;
  animation-name: hinge;
}

/* originally authored by Nick Pettit - https://github.com/nickpettit/glide */

@-webkit-keyframes rollIn {
  from {
    opacity: 0;
    -webkit-transform: translate3d(-100%, 0, 0) rotate3d(0, 0, 1, -120deg);
    transform: translate3d(-100%, 0, 0) rotate3d(0, 0, 1, -120deg);
  }

  to {
    opacity: 1;
    -webkit-transform: none;
    transform: none;
  }
}

@keyframes rollIn {
  from {
    opacity: 0;
    -webkit-transform: translate3d(-100%, 0, 0) rotate3d(0, 0, 1, -120deg);
    transform: translate3d(-100%, 0, 0) rotate3d(0, 0, 1, -120deg);
  }

  to {
    opacity: 1;
    -webkit-transform: none;
    transform: none;
  }
}

.rollIn {
  -webkit-animation-name: rollIn;
  animation-name: rollIn;
}

/* originally authored by Nick Pettit - https://github.com/nickpettit/glide */

@-webkit-keyframes rollOut {
  from {
    opacity: 1;
  }

  to {
    opacity: 0;
    -webkit-transform: translate3d(100%, 0, 0) rotate3d(0, 0, 1, 120deg);
    transform: translate3d(100%, 0, 0) rotate3d(0, 0, 1, 120deg);
  }
}

@keyframes rollOut {
  from {
    opacity: 1;
  }

  to {
    opacity: 0;
    -webkit-transform: translate3d(100%, 0, 0) rotate3d(0, 0, 1, 120deg);
    transform: translate3d(100%, 0, 0) rotate3d(0, 0, 1, 120deg);
  }
}

.rollOut {
  -webkit-animation-name: rollOut;
  animation-name: rollOut;
}

@-webkit-keyframes zoomIn {
  from {
    opacity: 0;
    -webkit-transform: scale3d(.3, .3, .3);
    transform: scale3d(.3, .3, .3);
  }

  50% {
    opacity: 1;
  }
}

@keyframes zoomIn {
  from {
    opacity: 0;
    -webkit-transform: scale3d(.3, .3, .3);
    transform: scale3d(.3, .3, .3);
  }

  50% {
    opacity: 1;
  }
}

.zoomIn {
  -webkit-animation-name: zoomIn;
  animation-name: zoomIn;
}

@-webkit-keyframes zoomInDown {
  from {
    opacity: 0;
    -webkit-transform: scale3d(.1, .1, .1) translate3d(0, -1000px, 0);
    transform: scale3d(.1, .1, .1) translate3d(0, -1000px, 0);
    -webkit-animation-timing-function: cubic-bezier(0.550, 0.055, 0.675, 0.190);
    animation-timing-function: cubic-bezier(0.550, 0.055, 0.675, 0.190);
  }

  60% {
    opacity: 1;
    -webkit-transform: scale3d(.475, .475, .475) translate3d(0, 60px, 0);
    transform: scale3d(.475, .475, .475) translate3d(0, 60px, 0);
    -webkit-animation-timing-function: cubic-bezier(0.175, 0.885, 0.320, 1);
    animation-timing-function: cubic-bezier(0.175, 0.885, 0.320, 1);
  }
}

@keyframes zoomInDown {
  from {
    opacity: 0;
    -webkit-transform: scale3d(.1, .1, .1) translate3d(0, -1000px, 0);
    transform: scale3d(.1, .1, .1) translate3d(0, -1000px, 0);
    -webkit-animation-timing-function: cubic-bezier(0.550, 0.055, 0.675, 0.190);
    animation-timing-function: cubic-bezier(0.550, 0.055, 0.675, 0.190);
  }

  60% {
    opacity: 1;
    -webkit-transform: scale3d(.475, .475, .475) translate3d(0, 60px, 0);
    transform: scale3d(.475, .475, .475) translate3d(0, 60px, 0);
    -webkit-animation-timing-function: cubic-bezier(0.175, 0.885, 0.320, 1);
    animation-timing-function: cubic-bezier(0.175, 0.885, 0.320, 1);
  }
}

.zoomInDown {
  -webkit-animation-name: zoomInDown;
  animation-name: zoomInDown;
}

@-webkit-keyframes zoomInLeft {
  from {
    opacity: 0;
    -webkit-transform: scale3d(.1, .1, .1) translate3d(-1000px, 0, 0);
    transform: scale3d(.1, .1, .1) translate3d(-1000px, 0, 0);
    -webkit-animation-timing-function: cubic-bezier(0.550, 0.055, 0.675, 0.190);
    animation-timing-function: cubic-bezier(0.550, 0.055, 0.675, 0.190);
  }

  60% {
    opacity: 1;
    -webkit-transform: scale3d(.475, .475, .475) translate3d(10px, 0, 0);
    transform: scale3d(.475, .475, .475) translate3d(10px, 0, 0);
    -webkit-animation-timing-function: cubic-bezier(0.175, 0.885, 0.320, 1);
    animation-timing-function: cubic-bezier(0.175, 0.885, 0.320, 1);
  }
}

@keyframes zoomInLeft {
  from {
    opacity: 0;
    -webkit-transform: scale3d(.1, .1, .1) translate3d(-1000px, 0, 0);
    transform: scale3d(.1, .1, .1) translate3d(-1000px, 0, 0);
    -webkit-animation-timing-function: cubic-bezier(0.550, 0.055, 0.675, 0.190);
    animation-timing-function: cubic-bezier(0.550, 0.055, 0.675, 0.190);
  }

  60% {
    opacity: 1;
    -webkit-transform: scale3d(.475, .475, .475) translate3d(10px, 0, 0);
    transform: scale3d(.475, .475, .475) translate3d(10px, 0, 0);
    -webkit-animation-timing-function: cubic-bezier(0.175, 0.885, 0.320, 1);
    animation-timing-function: cubic-bezier(0.175, 0.885, 0.320, 1);
  }
}

.zoomInLeft {
  -webkit-animation-name: zoomInLeft;
  animation-name: zoomInLeft;
}

@-webkit-keyframes zoomInRight {
  from {
    opacity: 0;
    -webkit-transform: scale3d(.1, .1, .1) translate3d(1000px, 0, 0);
    transform: scale3d(.1, .1, .1) translate3d(1000px, 0, 0);
    -webkit-animation-timing-function: cubic-bezier(0.550, 0.055, 0.675, 0.190);
    animation-timing-function: cubic-bezier(0.550, 0.055, 0.675, 0.190);
  }

  60% {
    opacity: 1;
    -webkit-transform: scale3d(.475, .475, .475) translate3d(-10px, 0, 0);
    transform: scale3d(.475, .475, .475) translate3d(-10px, 0, 0);
    -webkit-animation-timing-function: cubic-bezier(0.175, 0.885, 0.320, 1);
    animation-timing-function: cubic-bezier(0.175, 0.885, 0.320, 1);
  }
}

@keyframes zoomInRight {
  from {
    opacity: 0;
    -webkit-transform: scale3d(.1, .1, .1) translate3d(1000px, 0, 0);
    transform: scale3d(.1, .1, .1) translate3d(1000px, 0, 0);
    -webkit-animation-timing-function: cubic-bezier(0.550, 0.055, 0.675, 0.190);
    animation-timing-function: cubic-bezier(0.550, 0.055, 0.675, 0.190);
  }

  60% {
    opacity: 1;
    -webkit-transform: scale3d(.475, .475, .475) translate3d(-10px, 0, 0);
    transform: scale3d(.475, .475, .475) translate3d(-10px, 0, 0);
    -webkit-animation-timing-function: cubic-bezier(0.175, 0.885, 0.320, 1);
    animation-timing-function: cubic-bezier(0.175, 0.885, 0.320, 1);
  }
}

.zoomInRight {
  -webkit-animation-name: zoomInRight;
  animation-name: zoomInRight;
}

@-webkit-keyframes zoomInUp {
  from {
    opacity: 0;
    -webkit-transform: scale3d(.1, .1, .1) translate3d(0, 1000px, 0);
    transform: scale3d(.1, .1, .1) translate3d(0, 1000px, 0);
    -webkit-animation-timing-function: cubic-bezier(0.550, 0.055, 0.675, 0.190);
    animation-timing-function: cubic-bezier(0.550, 0.055, 0.675, 0.190);
  }

  60% {
    opacity: 1;
    -webkit-transform: scale3d(.475, .475, .475) translate3d(0, -60px, 0);
    transform: scale3d(.475, .475, .475) translate3d(0, -60px, 0);
    -webkit-animation-timing-function: cubic-bezier(0.175, 0.885, 0.320, 1);
    animation-timing-function: cubic-bezier(0.175, 0.885, 0.320, 1);
  }
}

@keyframes zoomInUp {
  from {
    opacity: 0;
    -webkit-transform: scale3d(.1, .1, .1) translate3d(0, 1000px, 0);
    transform: scale3d(.1, .1, .1) translate3d(0, 1000px, 0);
    -webkit-animation-timing-function: cubic-bezier(0.550, 0.055, 0.675, 0.190);
    animation-timing-function: cubic-bezier(0.550, 0.055, 0.675, 0.190);
  }

  60% {
    opacity: 1;
    -webkit-transform: scale3d(.475, .475, .475) translate3d(0, -60px, 0);
    transform: scale3d(.475, .475, .475) translate3d(0, -60px, 0);
    -webkit-animation-timing-function: cubic-bezier(0.175, 0.885, 0.320, 1);
    animation-timing-function: cubic-bezier(0.175, 0.885, 0.320, 1);
  }
}

.zoomInUp {
  -webkit-animation-name: zoomInUp;
  animation-name: zoomInUp;
}

@-webkit-keyframes zoomOut {
  from {
    opacity: 1;
  }

  50% {
    opacity: 0;
    -webkit-transform: scale3d(.3, .3, .3);
    transform: scale3d(.3, .3, .3);
  }

  to {
    opacity: 0;
  }
}

@keyframes zoomOut {
  from {
    opacity: 1;
  }

  50% {
    opacity: 0;
    -webkit-transform: scale3d(.3, .3, .3);
    transform: scale3d(.3, .3, .3);
  }

  to {
    opacity: 0;
  }
}

.zoomOut {
  -webkit-animation-name: zoomOut;
  animation-name: zoomOut;
}

@-webkit-keyframes zoomOutDown {
  40% {
    opacity: 1;
    -webkit-transform: scale3d(.475, .475, .475) translate3d(0, -60px, 0);
    transform: scale3d(.475, .475, .475) translate3d(0, -60px, 0);
    -webkit-animation-timing-function: cubic-bezier(0.550, 0.055, 0.675, 0.190);
    animation-timing-function: cubic-bezier(0.550, 0.055, 0.675, 0.190);
  }

  to {
    opacity: 0;
    -webkit-transform: scale3d(.1, .1, .1) translate3d(0, 2000px, 0);
    transform: scale3d(.1, .1, .1) translate3d(0, 2000px, 0);
    -webkit-transform-origin: center bottom;
    transform-origin: center bottom;
    -webkit-animation-timing-function: cubic-bezier(0.175, 0.885, 0.320, 1);
    animation-timing-function: cubic-bezier(0.175, 0.885, 0.320, 1);
  }
}

@keyframes zoomOutDown {
  40% {
    opacity: 1;
    -webkit-transform: scale3d(.475, .475, .475) translate3d(0, -60px, 0);
    transform: scale3d(.475, .475, .475) translate3d(0, -60px, 0);
    -webkit-animation-timing-function: cubic-bezier(0.550, 0.055, 0.675, 0.190);
    animation-timing-function: cubic-bezier(0.550, 0.055, 0.675, 0.190);
  }

  to {
    opacity: 0;
    -webkit-transform: scale3d(.1, .1, .1) translate3d(0, 2000px, 0);
    transform: scale3d(.1, .1, .1) translate3d(0, 2000px, 0);
    -webkit-transform-origin: center bottom;
    transform-origin: center bottom;
    -webkit-animation-timing-function: cubic-bezier(0.175, 0.885, 0.320, 1);
    animation-timing-function: cubic-bezier(0.175, 0.885, 0.320, 1);
  }
}

.zoomOutDown {
  -webkit-animation-name: zoomOutDown;
  animation-name: zoomOutDown;
}

@-webkit-keyframes zoomOutLeft {
  40% {
    opacity: 1;
    -webkit-transform: scale3d(.475, .475, .475) translate3d(42px, 0, 0);
    transform: scale3d(.475, .475, .475) translate3d(42px, 0, 0);
  }

  to {
    opacity: 0;
    -webkit-transform: scale(.1) translate3d(-2000px, 0, 0);
    transform: scale(.1) translate3d(-2000px, 0, 0);
    -webkit-transform-origin: left center;
    transform-origin: left center;
  }
}

@keyframes zoomOutLeft {
  40% {
    opacity: 1;
    -webkit-transform: scale3d(.475, .475, .475) translate3d(42px, 0, 0);
    transform: scale3d(.475, .475, .475) translate3d(42px, 0, 0);
  }

  to {
    opacity: 0;
    -webkit-transform: scale(.1) translate3d(-2000px, 0, 0);
    transform: scale(.1) translate3d(-2000px, 0, 0);
    -webkit-transform-origin: left center;
    transform-origin: left center;
  }
}

.zoomOutLeft {
  -webkit-animation-name: zoomOutLeft;
  animation-name: zoomOutLeft;
}

@-webkit-keyframes zoomOutRight {
  40% {
    opacity: 1;
    -webkit-transform: scale3d(.475, .475, .475) translate3d(-42px, 0, 0);
    transform: scale3d(.475, .475, .475) translate3d(-42px, 0, 0);
  }

  to {
    opacity: 0;
    -webkit-transform: scale(.1) translate3d(2000px, 0, 0);
    transform: scale(.1) translate3d(2000px, 0, 0);
    -webkit-transform-origin: right center;
    transform-origin: right center;
  }
}

@keyframes zoomOutRight {
  40% {
    opacity: 1;
    -webkit-transform: scale3d(.475, .475, .475) translate3d(-42px, 0, 0);
    transform: scale3d(.475, .475, .475) translate3d(-42px, 0, 0);
  }

  to {
    opacity: 0;
    -webkit-transform: scale(.1) translate3d(2000px, 0, 0);
    transform: scale(.1) translate3d(2000px, 0, 0);
    -webkit-transform-origin: right center;
    transform-origin: right center;
  }
}

.zoomOutRight {
  -webkit-animation-name: zoomOutRight;
  animation-name: zoomOutRight;
}

@-webkit-keyframes zoomOutUp {
  40% {
    opacity: 1;
    -webkit-transform: scale3d(.475, .475, .475) translate3d(0, 60px, 0);
    transform: scale3d(.475, .475, .475) translate3d(0, 60px, 0);
    -webkit-animation-timing-function: cubic-bezier(0.550, 0.055, 0.675, 0.190);
    animation-timing-function: cubic-bezier(0.550, 0.055, 0.675, 0.190);
  }

  to {
    opacity: 0;
    -webkit-transform: scale3d(.1, .1, .1) translate3d(0, -2000px, 0);
    transform: scale3d(.1, .1, .1) translate3d(0, -2000px, 0);
    -webkit-transform-origin: center bottom;
    transform-origin: center bottom;
    -webkit-animation-timing-function: cubic-bezier(0.175, 0.885, 0.320, 1);
    animation-timing-function: cubic-bezier(0.175, 0.885, 0.320, 1);
  }
}

@keyframes zoomOutUp {
  40% {
    opacity: 1;
    -webkit-transform: scale3d(.475, .475, .475) translate3d(0, 60px, 0);
    transform: scale3d(.475, .475, .475) translate3d(0, 60px, 0);
    -webkit-animation-timing-function: cubic-bezier(0.550, 0.055, 0.675, 0.190);
    animation-timing-function: cubic-bezier(0.550, 0.055, 0.675, 0.190);
  }

  to {
    opacity: 0;
    -webkit-transform: scale3d(.1, .1, .1) translate3d(0, -2000px, 0);
    transform: scale3d(.1, .1, .1) translate3d(0, -2000px, 0);
    -webkit-transform-origin: center bottom;
    transform-origin: center bottom;
    -webkit-animation-timing-function: cubic-bezier(0.175, 0.885, 0.320, 1);
    animation-timing-function: cubic-bezier(0.175, 0.885, 0.320, 1);
  }
}

.zoomOutUp {
  -webkit-animation-name: zoomOutUp;
  animation-name: zoomOutUp;
}

@-webkit-keyframes slideInDown {
  from {
    -webkit-transform: translate3d(0, -100%, 0);
    transform: translate3d(0, -100%, 0);
    visibility: visible;
  }

  to {
    -webkit-transform: translate3d(0, 0, 0);
    transform: translate3d(0, 0, 0);
  }
}

@keyframes slideInDown {
  from {
    -webkit-transform: translate3d(0, -100%, 0);
    transform: translate3d(0, -100%, 0);
    visibility: visible;
  }

  to {
    -webkit-transform: translate3d(0, 0, 0);
    transform: translate3d(0, 0, 0);
  }
}

.slideInDown {
  -webkit-animation-name: slideInDown;
  animation-name: slideInDown;
}

@-webkit-keyframes slideInLeft {
  from {
    -webkit-transform: translate3d(-100%, 0, 0);
    transform: translate3d(-100%, 0, 0);
    visibility: visible;
  }

  to {
    -webkit-transform: translate3d(0, 0, 0);
    transform: translate3d(0, 0, 0);
  }
}

@keyframes slideInLeft {
  from {
    -webkit-transform: translate3d(-100%, 0, 0);
    transform: translate3d(-100%, 0, 0);
    visibility: visible;
  }

  to {
    -webkit-transform: translate3d(0, 0, 0);
    transform: translate3d(0, 0, 0);
  }
}

.slideInLeft {
  -webkit-animation-name: slideInLeft;
  animation-name: slideInLeft;
}

@-webkit-keyframes slideInRight {
  from {
    -webkit-transform: translate3d(100%, 0, 0);
    transform: translate3d(100%, 0, 0);
    visibility: visible;
  }

  to {
    -webkit-transform: translate3d(0, 0, 0);
    transform: translate3d(0, 0, 0);
  }
}

@keyframes slideInRight {
  from {
    -webkit-transform: translate3d(100%, 0, 0);
    transform: translate3d(100%, 0, 0);
    visibility: visible;
  }

  to {
    -webkit-transform: translate3d(0, 0, 0);
    transform: translate3d(0, 0, 0);
  }
}

.slideInRight {
  -webkit-animation-name: slideInRight;
  animation-name: slideInRight;
}

@-webkit-keyframes slideInUp {
  from {
    -webkit-transform: translate3d(0, 100%, 0);
    transform: translate3d(0, 100%, 0);
    visibility: visible;
  }

  to {
    -webkit-transform: translate3d(0, 0, 0);
    transform: translate3d(0, 0, 0);
  }
}

@keyframes slideInUp {
  from {
    -webkit-transform: translate3d(0, 100%, 0);
    transform: translate3d(0, 100%, 0);
    visibility: visible;
  }

  to {
    -webkit-transform: translate3d(0, 0, 0);
    transform: translate3d(0, 0, 0);
  }
}

.slideInUp {
  -webkit-animation-name: slideInUp;
  animation-name: slideInUp;
}

@-webkit-keyframes slideOutDown {
  from {
    -webkit-transform: translate3d(0, 0, 0);
    transform: translate3d(0, 0, 0);
  }

  to {
    visibility: hidden;
    -webkit-transform: translate3d(0, 100%, 0);
    transform: translate3d(0, 100%, 0);
  }
}

@keyframes slideOutDown {
  from {
    -webkit-transform: translate3d(0, 0, 0);
    transform: translate3d(0, 0, 0);
  }

  to {
    visibility: hidden;
    -webkit-transform: translate3d(0, 100%, 0);
    transform: translate3d(0, 100%, 0);
  }
}

.slideOutDown {
  -webkit-animation-name: slideOutDown;
  animation-name: slideOutDown;
}

@-webkit-keyframes slideOutLeft {
  from {
    -webkit-transform: translate3d(0, 0, 0);
    transform: translate3d(0, 0, 0);
  }

  to {
    visibility: hidden;
    -webkit-transform: translate3d(-100%, 0, 0);
    transform: translate3d(-100%, 0, 0);
  }
}

@keyframes slideOutLeft {
  from {
    -webkit-transform: translate3d(0, 0, 0);
    transform: translate3d(0, 0, 0);
  }

  to {
    visibility: hidden;
    -webkit-transform: translate3d(-100%, 0, 0);
    transform: translate3d(-100%, 0, 0);
  }
}

.slideOutLeft {
  -webkit-animation-name: slideOutLeft;
  animation-name: slideOutLeft;
}

@-webkit-keyframes slideOutRight {
  from {
    -webkit-transform: translate3d(0, 0, 0);
    transform: translate3d(0, 0, 0);
  }

  to {
    visibility: hidden;
    -webkit-transform: translate3d(100%, 0, 0);
    transform: translate3d(100%, 0, 0);
  }
}

@keyframes slideOutRight {
  from {
    -webkit-transform: translate3d(0, 0, 0);
    transform: translate3d(0, 0, 0);
  }

  to {
    visibility: hidden;
    -webkit-transform: translate3d(100%, 0, 0);
    transform: translate3d(100%, 0, 0);
  }
}

.slideOutRight {
  -webkit-animation-name: slideOutRight;
  animation-name: slideOutRight;
}

@-webkit-keyframes slideOutUp {
  from {
    -webkit-transform: translate3d(0, 0, 0);
    transform: translate3d(0, 0, 0);
  }

  to {
    visibility: hidden;
    -webkit-transform: translate3d(0, -100%, 0);
    transform: translate3d(0, -100%, 0);
  }
}

@keyframes slideOutUp {
  from {
    -webkit-transform: translate3d(0, 0, 0);
    transform: translate3d(0, 0, 0);
  }

  to {
    visibility: hidden;
    -webkit-transform: translate3d(0, -100%, 0);
    transform: translate3d(0, -100%, 0);
  }
}

.slideOutUp {
  -webkit-animation-name: slideOutUp;
  animation-name: slideOutUp;
}

@media (min-width: 1600px) {
  .blog-home .blog-posts .blog-post-content {
    min-height: 275px;
  }

  .gallery {
    margin-top: 8%
  }
}

@media (max-width: 1300px) {
  .blog-home .blog-posts .blog-post-content {
    min-height: 221px;
  }
}

@media (max-width: 1400px) {
  .portfolio {
    top: -250px;
    margin-bottom: -250px !important;
  }
}

@media (max-width: 1280px) {
  p {
    font-size: 0.8em
  }

  h2.section-title {
    margin-bottom: 15px !important;
    font-size: 2em;
  }

  .portfolio {
    top: -240px;
    margin-bottom: -240px !important;
  }

  .btn.btn-lg {
    font-size: 0.8em !important;
    padding: 10px 50px !important;
    margin-top: -10px
  }

  .blog-home .blog-posts .blog-post-content {
    min-height: 199px;
  }

  .chart h3.widget-title {
    width: 141px !important;
  }
}

@media (max-width: 1180px) and (min-width: 768px) {
  .nav-desktop .site-header .nav-menu>ul>li+li {
    margin-left: 15px !important;
  }

  .nav-desktop .site-header .nav-menu>ul>li a {
    padding: 15px 0px 35px !important;
  }

  .nav-desktop .site-header .nav-menu>ul>li.menu-item-has-children a {
    padding-right: 15px !important;
  }

  .nav-desktop .site-header .nav-menu .sub-menu a {
    padding: 9px 10px !important;
  }

  .filter .equipoBtn {
    font-size: 0.8em;
  }
}

@media (max-width: 978px) {
  .filter {
    width: 100%;
    background: #E5E5E5;
    padding: 1.2em 1em !important;
    margin: 0
  }

  .filter-team:after {
    position: absolute;
    right: 13px;
    top: 8px;
    color: #333;
    content: "\f007  \f007  \f007" !important;
    font-family: FontAwesome;
    font-size: 0.9em;
    cursor: pointer
  }

  .filter-team:before {
    position: absolute;
    right: 70px;
    top: 9px;
    color: #333;
    content: "Filtrar Equipos por Pa\00EDs:" !important;
    font-weight: bold;
    font-size: 0.8em;
  }

  .filter-team div {
    display: none;
    position: fixed;
    width: 100%;
    height: 100%;
    background: rgba(0, 0, 0, 0.8);
    margin: 0;
    top: 121px;
    left: 0;
  }

  .filter .equipoBtn {
    font-size: 0.7em !important;
    line-height: 3em !important;
  }

  .filter-team .equipoBtn {
    display: block !important;
    color: #fff;
  }

  .filter .equipoBtn.active:after {
    display: none
  }

  .portfolio {
    top: -275px;
    margin-bottom: -275px !important;
  }

  .proyects .more {
    margin-bottom: 20px !important;
    top: -25px !important;
    padding: 0 !important;
    border: 0 !important;
  }

  .slider-home-top .tp-caption.noshadow,
  .slider-team-top .tp-caption.noshadow {
    font-size: 1.5em !important;
  }

  .nav-desktop .site-header .nav-menu .sub-menu a {
    color: #999 !important
  }

  .nav-desktop .site-header .nav-menu .sub-menu a:hover {
    color: #fff !important;
    background: none !important
  }

  .filter-link {
    display: none
  }

  .page_full_width {
    z-index: 100 !important;
    position: relative;

  }

}

@media (max-width: 767px) {
  .fixed-top-affix {
    top: 70px;
  }

  .admin-bar .fixed-top-affix {
    top: 121px;
  }

  .nav-row {

    z-index: 1001 !important
  }

  .page_full_width {
    z-index: 100 !important;
    position: relative;

  }

  .panel-grid {
    margin-left: 0 !important;
    margin-right: 0 !important;
    margin-bottom: 58px !important;
  }

  .panel-grid .panel-row-style,
  .panel-grid .text-padding {
    padding-left: 15px !important;
    padding-right: 15px !important;
  }

  .panel-grid .fixed-top-affix,
  .fixed-top-affix .panel-grid .panel-row-style,
  .panel-grid .fixed-top,
  .fixed-top .panel-grid .panel-row-style {
    padding-left: 0 !important;
    padding-right: 0 !important;
  }

  .site-header .nav-menu a {
    color: #FFF !important;
    font-size: 0.5em !important;
  }

  .nav-desktop.nav-open .site-header .nav-toggle:before {
    color: #333 !important;
  }

  .nav-desktop .site-header .nav-menu .sub-menu {
    margin-top: 5px !important;
  }

  .site-header .nav-menu li+li {
    margin-top: 5px !important;
  }

  .tp-caption.BigBold-Title,
  .BigBold-Title {
    transform: none !important;
    text-align: center
  }

  .portfolio {
    top: -150px !important;
    margin-bottom: -150px !important;
    margin-left: -7px !important;
    margin-right: -7px !important;
  }

  .portfolio.portfolio-masonry-spacing article {
    width: 50% !important;
  }

  .portfolio.portfolio-masonry-spacing article:nth-child(3) {
    margin-top: 0 !important;
  }

  .color {
    margin-left: -15px !important;
    margin-right: -15px !important;
    padding-left: 30px !important;
    padding-right: 30px !important;
  }

  .blog-posts header a {
    top: 0;
  }

  .blog-posts .blog-post-author {
    display: none !important;
  }

  .blog-posts footer {
    bottom: 10px;
  }

  .blog-load-more {
    margin-top: 20px
  }

  footer .wpcf7-form {
    width: 100%
  }

  footer .wpcf7-form p {
    width: 50%
  }

  footer .widget_text,
  footer .widget_search {
    width: 48%;
  }

  .animatable {
    visibility: visible;
  }

  .team-text {
    padding-left: 15px !important;
    padding-right: 15px !important;
    padding-top: 40px !important;
    padding-bottom: 40px !important;
  }

  .more {
    margin-bottom: 15px !important;
    border: 0 !important
  }

  .slider-home-top .tp-caption.noshadow,
  .slider-team-top .tp-caption.noshadow {
    font-size: 1.3em !important;
  }

  h3.widget-title {
    width: 90%;
    font-size: 1.5em !important;
    position: relative !important;
    top: 15px !important;
    margin: 10px 20px !important;
  }

  #rowsCasos {
    float: none;
    width: 100% !important;
    padding-left: 0;
  }

  #rowsCasos .bolder td {
    font-size: 1.1em !important;
  }

  .filtrosWp .filter {
    padding: 0 !important;
  }

  .styled-select {
    margin-right: 12px;
    width: 50px;
  }

  .styled-select3 {
    width: 85px;
  }

  .chart h3.widget-title {
    width: 100% !important;
  }

  .arrow-top {
    float: none !important
  }

  .slider-history-top .tp-parallax-wrap {
    /*display: none*/
    left: 10% !important;
    min-width: 100% !important;
    max-width: 100% !important;
  }

  .slider-history-top .tp-mask-wrap,
  .slider-history-top .tp-loop-wrap {
    width: 90% !important;
  }

  #slide-24-layer-1 {
    font-size: 0.7em !important;
    min-width: 100% !important;
    max-width: 100% !important;
  }

  .talk-home {
    margin-top: 0 !important
  }

  .portfolio-post-header-meta li.superficier,
  .portfolio-post-header-meta li.plazo_de_la_obra {
    width: 100%;
    font-size: 0.8em !important;
  }

  .gallery-item:nth-child(3),
  .gallery-item:nth-child(5) {
    width: 100% !important
  }

  .gallery-item:nth-child(3) {
    margin-top: 0;
  }

  .gallery-item:nth-child(8) {
    margin-top: 0;
  }

  .color-last .panel-grid-cell:last-child {
    margin: 0 -15px;
    padding: 15px 15px 30px !important;
  }

  .proyectos-relacionados-items {
    margin: 0
  }

  .proyectos-relacionados .portfolio-item {
    float: none;
    width: 100% !important;
  }

  .proyectos-relacionados .portfolio-item a {
    margin: 15px 0;
  }

  .gallery-item {
    width: 100% !important
  }

  .nav-tabs {

    margin-left: -10px !important;

    margin-right: -10px !important;

  }

  .nav-tabs>li {
    width: auto !important
  }

  .nav-tabs>li>a {
    padding-top: 100px !important;
    width: 100px !important;
    font-size: 0.7em !important;
    padding: 10px 0 !important;
  }

  .nav-tabs>li>a:before {
    width: 90px !important;
    height: 90px !important;
    background-position: 50% 0 !important;
    left: 0 !important;
  }

  .nav-tabs>li>a[href="#tab-1-1"]:before {
    background-position: 50% -172px !important
  }

  .nav-tabs>li>a[href="#tab-1-2"]:before {
    background-position: 50% -314px !important
  }

  .columnas p {
    font-size: 0.7em !important;
  }

}

@media (max-width: 585px) {

  .fixed-top-affix,
  .admin-bar .fixed-top-affix {
    top: 70px;
  }
}

@media (max-width: 484px) {
  .fixed-top-affix {
    top: 75px;
  }

  .portfolio.portfolio-masonry-spacing article,
  .portfolio.portfolio-masonry-spacing article.portfolio-large {
    width: 100% !important;
  }

  .panel-widget-style-home .sow-features-list .sow-features-feature .textwidget,
  .panel-widget-style-home .sow-features-list .sow-features-feature .textwidget p {
    margin-left: 0 !important;
    text-align: center !important
  }

  .panel-widget-style-interna .so-widget-sow-features .sow-features-feature {
    text-align: center
  }

  .sow-features-list .sow-features-feature .textwidget {
    margin-left: 0 !important;
  }

  .panel-widget-style-interna .so-widget-sow-features .sow-features-list .sow-features-feature .sow-icon-container {
    display: block;
    text-align: center
  }

  .panel-widget-style-interna .so-widget-sow-features .sow-features-list .sow-features-feature .textwidget h5 {

    font-size: 1em !important
  }

  .panel-widget-style-home .sow-features-list .sow-features-feature .sow-icon-container {
    position: relative;
    top: auto;
    margin-top: 20px;
    margin-bottom: 0;
    left: 50%;
    margin-left: -54px;
  }

  .blog-home .blog-posts {
    margin-left: auto !important;
    margin-right: auto !important;
  }

  .blog-home .blog-posts header a {
    top: 0;
  }

  .contact-down .btn {
    width: 100%
  }

  footer .widget_text,
  footer .widget_search {
    width: 95%;
  }

  .slider-home-top .tp-caption.noshadow,
  .slider-team-top .tp-caption.noshadow {
    font-size: 1em !important;
  }

  .forcefullwidth_wrapper_tp_banner {
    padding-top: 0 !important;
    margin-top: 0 !important;
  }

  #rowsCasos .bolder td {
    font-size: 0.85em !important;
  }

  #rowsCasos td {
    font-size: 0.75em !important;
  }

  .styled-select select {

    width: 110% !important;

  }

  .styled-select {

    width: 100% !important;

    margin-bottom: 10px !important
  }

  .video-interna {

    margin-top: -100px !important;

  }

  .video-interna .social-contact {
    margin-top: -30px;
    margin-bottom: 40px;
  }

  .video-interna:first-child {

    padding-top: 80px !important;

    margin-bottom: -80px !important;

  }

  .filter .text-left,

  .filter .text-right {

    float: none !important;

    display: block;

    text-align: left !important
  }

  .filter .text-right .equipoBtn {

    display: block;

  }

  .imageWp .containerPresupuesto {

    width: 200px;

    height: 110px;

    padding-top: 20px;

    border-radius: 0
  }

  .imageWp .containerPresupuesto h3 {

    font-size: 1.5em !important;

    margin-top: -20px !important
  }

  .imageWp .containerPresupuesto a {

    display: none
  }

  .progress-wrap .progress-title {
    font-size: 0.65em !important;
    line-height: 160% !important;
  }

  .filtros strong {
    font-size: 0.7em !important;
  }

  .page-id-392 #pgc-392-0-2 {
    height: auto !important;
  }

  #pgc-392-1-1 {
    margin: 0 !important
  }

  .domicilioempres,
  .codigopostal,
  .Telefono,
  .Fax,
  .provincia,
  .Pais {
    float: none !important;
    width: 100% !important;
  }

  .provincia {
    margin-bottom: 20px !important;
    display: block;
  }
}

@media (max-width: 480px) {

  .chart div.wp-chart-wrap,
  .chart .wp_charts_canvas {
    width: 141px !important;
    height: 141px !important;
  }

  #map {
    height: 300px !important
  }
}

/*Edicion Sabri*/
.nav-tabs {
  margin: 0 auto;
  text-align: center
}

.nav-tabs>li {
  position: relative;
  margin: 0 !important;
  display: inline-block !important;
  float: none !important;
  padding-bottom: 20px;
}

.nav-tabs>li>a {
  position: relative;
  background-color: none;
  border: 1px solid #fff !important;
  background: transparent !important;
  font-size: 1.3em;
  /*** Edicion Anto Valor anterior: 1.7em ***/
  font-weight: bold !important;
  opacity: 0.5;
  padding-top: 150px !important;
  width: 182px;
  margin: 0 !important;

}

.nav-tabs>li>a:before {
  position: absolute;
  top: 0;
  left: 20px;
  content: "";
  background: url(tabs.png) 0 0 transparent;
  /*background-size: 102px 328px;*/
  width: 142px;
  /*** Edicion Anto Valor anterior: 142px, le puse 100px ***/
  height: 142px;
  /*** Edicion Anto Valor anterior: 142px, le puse 100px ***/
  border-radius: 100% !important;
}

.nav-tabs>li.active>a,
.nav-tabs>li.active>a:hover,
.nav-tabs>li.active>a:focus {
  margin: 0 !important;
  opacity: 1
}

.nav-tabs>li.active>a:before {
  border: 1px solid #000 !important;
}

.nav-tabs>li>a[href="#tab-1-1"]:before {
  background-position: 0 -142px
}

.nav-tabs>li>a[href="#tab-1-2"]:before {
  background-position: 0 -284px
}

.nav-tabs>li.active:after,
.nav-tabs>li.active:before {
  bottom: 1px;
  /*** Edicion Anto Valor anterior: 0 ***/
  left: 50%;
  border: solid transparent;
  content: " ";
  height: 0;
  width: 0;
  position: absolute;
  pointer-events: none;
}

.nav-tabs>li.active:after {
  border-color: rgba(255, 255, 255, 0);
  border-bottom-color: #ffffff;
  border-width: 10px;
  margin-left: -10px;
}

.nav-tabs>li.active:before {
  border-color: rgba(0, 0, 0, 0);
  border-bottom-color: #000000;
  border-width: 11px;
  /*** Edicion Anto Valor anterior: 13px ***/
  margin-left: -11px;
  /*** Edicion Anto Valor anterior: -13px ***/
}

.tab-content {
  padding: 19px 0 !important;
  border: 0 !important;
  border-top: 1.7px solid #000 !important;
  /*** Edicion Anto Valor anterior: 2px ***/
  margin-top: -2px;
}

.tab-content .columnas {
  width: 46%;
  float: left;
  margin-right: 4%
}

.tab-content .columnas:nth-child(2) {
  margin-right: 0;
  margin-left: 4%
}

.tab-content .columnas h1 {
  border-bottom: 1px solid rgb(0, 0, 0);
  padding-bottom: 20px;
  margin-bottom: 20px;
  margin-top: 30px;
}

.tab-content .columnas ul,
.tab-content .columnas li {
  position: relative;
  margin-left: 0;
  padding-left: 0;
  list-style: none
}

.tab-content .columnas li {
  border-bottom: 1px solid #ccc;
  min-height: 100px
}

.tab-content .columnas li p {
  font-size: 1.2em;
  color: #000 !important;
  display: table-cell;
  height: 100px;
  vertical-align: middle;
}

.tab-content .columnas li img {
  display: table-cell;
}

.tab-content .columnas:nth-child(2) li:after,
.tab-content .columnas:nth-child(2) li:before {
  left: -9%;
  top: 50%;
  border: solid transparent;
  content: " ";
  height: 0;
  width: 0;
  position: absolute;
  pointer-events: none;
}

.tab-content .columnas:nth-child(2) li:after {
  border-color: rgba(255, 255, 255, 0);
  border-left-color: #ffffff;
  border-width: 10px;
  margin-top: -10px;
}

.tab-content .columnas:nth-child(2) li:before {
  border-color: rgba(0, 0, 0, 0);
  border-left-color: #000000;
  border-width: 12px;
  margin-top: -12px;
}

/*Edicion Gabriel*/

.plazo_de_la_obra {
  width: 70% !important;
}

.superficier {
  width: 30% !important;
}

.portfolio {
  padding-bottom: 4em;
}

.portfolio.portfolio-masonry-spacing article.largeItem {
  width: 50% !important;
  margin-top: -18.7%;
  max-height: 714px;
}

.portfolio.portfolio-masonry-spacing article.largeItemOnGrid {
  width: 50% !important;

  max-height: 714px;
}

@media (max-width: 767px) {

  .portfolio.portfolio-masonry-spacing article.largeItem,

  .portfolio.portfolio-masonry-spacing article.largeItemOnGrid {
    width: 100% !important;

  }

}

#paginadorWp,
#paginadorWp2 {
  position: absolute;
  bottom: 0;
  width: 100%;
  margin: 0;
}

#paginadorWp2 {
  margin-bottom: -4em;

}

#paginadorWp2 p {
  width: 50%;
  margin: 0 25%;
  overflow: hidden;
  display: block;
  text-align: center !important;
}

#paginadorWp p {
  width: 65px;
  margin: 0 auto;
}

.botonGrilla,
.botonTabla {
  width: 10px;
  height: 10px;
  background: #333 !important;
  border: 2px solid transparent !important;
  margin: 1px 10px 1px 1px !important;
  text-indent: -9000px;
  border-radius: 50%;
  padding: 0 !important;
  float: none !important;
  display: inline-block;
}

.activeFilterPage {
  width: 12px !important;
  height: 12px !important;
  background: none !important;
  border: 2px solid #333 !important;

  text-indent: -9000px;
  border-radius: 50%;
  padding: 0 !important;
  position: relative;
  top: -1px;
}

.so-widget-sow-features-features-7171654e01fb .sow-features-list .sow-features-feature .textwidget>p {
  color: white !important;
}

#rowsCasos tr {

  width: 1275px !important;
}

#rowsCasos td {
  border: 0;
  border-bottom: 1px solid #ccc;
  padding-left: 20px;
  font-size: 0.9em;
  color: #777 !important;
  width: 25%;
  display: block;
  box-sizing: border-box;
  float: left;
}

#FiltroButton,
#FiltroButton2 {

  font-size: 0.7em !important;
  font-weight: bold !important;
  height: 32px;
  padding: 3px 20px !important;
  text-transform: uppercase;
  background: #E21737;
  color: #fff;
  border-radius: 0.3em;
  margin: 0 0 0 1em;
  border: none !important;
  box-sizing: border-box;
}

@media screen and (max-width: 767px) {
  #rowsCasos tr {
    width: auto !important;
    position: relative !important;
    top: auto !important;
    left: auto !important
  }

  #rowsCasos td {
    padding-left: 0 !important;
    font-size: 0.7em !important;
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: nowrap;
    width: 15% !important
  }

  #rowsCasos td:nth-child(1),
  #rowsCasos td:nth-child(2) {
    width: 35% !important
  }

  h3.widget-title {
    padding-left: 0 !important;
    margin-left: 0 !important
  }

  #FiltroButton,
  #FiltroButton2 {
    display: inline-block !important;
    margin-top: 10px !important
  }
}

.hs-tooltip,
.hs-tooltip-visible {

  text-align: center !important;
}

.pagina2,
.pagina3 {
  display: block;
}

.portfolio {
  height: auto !important;
}

.anossWp a {
  font-size: 0.7em !important;
  padding: 0 10px !important;
  line-height: 33px !important;
  font-weight: bold;
  text-transform: uppercase;
  margin: 0 1em 0 0;
}

.chart .panel-grid-cell {
  padding-left: 15px;
  padding-right: 15px;
  width: 16.6% !important;
  box-sizing: border-box;
}

span.wpcf7-list-item {
  margin-left: 2em;
  /*** Edicion Anto Valor anterior: 0.5 em ***/
  width: 45%;
  /* background: gainsboro; */
  display: block;
  float: left;
  margin-top: 7px;
  margin-bottom: 7px;
  font-size: 1.3em
}

.indice-pais {

  position: absolute;

  top: 40%;

}

@media (max-width: 767px) {

  .indice-pais {

    position: relative !important;

    top: 0 !important;

  }

  .arg .panel-grid-cell {

    width: 31% !important;

    float: left !important;

    margin-right: 2% !important;

  }

  .arg .panel-grid-cell:first-child {

    width: 100% !important;

    float: none !important;

    margin-right: 0 !important;

  }

  .filtros strong {

    min-height: 65px;

  }

}

@media (max-width: 767px) {
  span.wpcf7-list-item {
    width: 90%;
    font-size: 1em
  }

  .wpcf7-submit {
    width: auto !important
  }
}

.page-id-56 .portfolio article:nth-child(8) {
  margin-top: 0%;
}

@media (max-width: 767px) {
  .page-id-56 .portfolio article:nth-child(8) {
    margin-top: 0;
  }
}

#pg-56-5 {
  position: relative;
  z-index: 100;
}

.page-id-56 .page-nav {
  display: none;
}

/*** Edicion Anto ***/

/*** HOME ***/

/* Nuestros servicios */

@media (max-width: 1024px) {
  #panel-56-7-0-0 h2.title {
    font-size: 2.05em !important;
  }
}

@media (min-width: 1280px) {
  #panel-56-7-0-0 h2.title {
    font-size: 2.2em !important;
  }
}

/* Titulo de lista de servicios */

@media (max-width: 1366px) {
  .panel-widget-style-home .sow-features-list .sow-features-feature h5 {
    font-size: 0.9em !important;
  }
}

@media (max-width: 1280px) {
  .panel-widget-style-home .sow-features-list .sow-features-feature h5 {
    font-size: 0.9em !important;
  }
}

/*** NOSOTROS - INTRODUCCION ***/

/* Font regular para Los cambios en... */

#panel-1085-1-0-0 h2 {
  margin-top: -15px !important;
  margin-bottom: 0 !important;
  font-weight: 500;
}

/* Titulos, textos y parrafos de las columnas Desde - Hacia */

@media (max-width: 1366px) {
  .columnas h1 {
    font-size: 28px;
  }

  .columnas p {
    font-size: 1.1em !important;
  }

  #panel-1085-3-0-0 blockquote {
    font-size: 1.27em !important;
  }
}

@media (max-width: 1280px) {
  .columnas h1 {
    font-size: 27px;
  }

  .columnas p {
    font-size: 1.1em !important;
  }

  #panel-1085-3-0-0 blockquote {
    font-size: 1.2em !important;
  }
}

@media (max-width: 1024px) {
  .columnas h1 {
    font-size: 28px;
  }

  .columnas p {
    font-size: 1.1em !important;
  }

  #panel-1085-3-0-0 blockquote {
    font-size: 1.27em !important;
  }
}

@media (max-width: 767px) {
  .columnas p {
    font-size: 0.7em !important;
  }
}

/* Imagenes de las columnas */

.columnas li img {
  max-width: 53%;
  padding-top: 2.6%;
  padding-right: 4.3%;
}

@media (max-width: 767px) {
  .columnas li img {
    max-width: 43%;
  }
}

/*** NOSOTROS - EQUIPO ***/

/* Titulo y parrafo de Nuestra gente y titulo de Equipo regional */

@media (max-width: 1366px) {
  #panel-205-1-0-1 p {
    font-size: 0.7em;
  }

  #EquipoRegional {
    font-size: 1.89em !important;
  }
}

@media (max-width: 1280px) {
  #panel-205-1-0-1 p {
    font-size: 0.8em;
  }

  #EquipoRegional {
    font-size: 2em !important;
  }
}

@media (max-width: 1024px) {
  #panel-205-1-0-0 h2 {
    font-size: 2.1em !important;
  }

  #panel-205-1-0-1 p {
    font-size: 0.72em !important;
  }

  #EquipoRegional {
    font-size: 2.1em !important;
  }
}

/* Detalle del equipo */

.team .member em {
  font-family: 'Trebuchet MS';
  margin-top: 2%;
}

@media (max-width: 1366px) {
  .team .member h3 {
    font-size: 0.96em !important;
  }

  .team .member em {
    font-size: 0.72em !important;
  }
}

@media (max-width: 1280px) {
  .team .member h3 {
    font-size: 0.96em !important;
  }

  .team .member em {
    font-size: 0.72em !important;
  }
}

/*** NOSOTROS - HISTORIA Y PRESENCIA REGIONAL ***/

/*Titulo de Perfil corporativo */

@media (max-width: 1366px) {
  #panel-644-1-1-0 h2 {
    font-size: 34px !important;
  }

  #panel-644-1-1-0 p {
    font-size: 0.7em !important;
  }
}

@media (max-width: 1280px) {
  #panel-644-1-1-0 h2 {
    font-size: 32px !important;
  }

  #panel-644-1-1-0 p {
    font-size: 0.8em !important;
  }
}

@media (max-width: 1024px) {
  #panel-644-1-1-0 h2 {
    font-size: 36px !important;
  }

  #panel-644-1-1-0 p {
    font-size: 0.7em !important;
  }
}

/* Lista de Axiomas */

#panel-644-3-1-0 ul li {
  font-family: 'Trebuchet MS';
}

#panel-644-3-1-0 ul li strong {
  font-weight: bold !important;
}

@media (max-width: 1366px) {
  #panel-644-3-1-0 ul li {
    font-size: 0.7em !important;
  }
}

@media (max-width: 1280px) {
  #panel-644-3-1-0 ul li {
    font-size: 0.8em !important;
  }
}

@media (max-width: 1024px) {
  #panel-644-3-1-0 ul li {
    font-size: 0.7em !important;
  }
}

/* Alineacion central del contenido */

#pg-644-1 .panel-grid-cell,
#pg-644-2 .panel-grid-cell,
#pg-644-3 .panel-grid-cell {
  padding-left: 32px !important;
  padding-right: 32px !important;
}

/*** CONTACTO - SEA PROVEEDOR ***/

/* Bloque titulo y parrafos */

#pg-2363-1 .panel-row-style {
  padding: 65px;
  margin-top: -59px;
}

#panel-2363-1-1-0 h1 {
  margin-bottom: 55px;
}

#panel-2363-1-1-0 p {
  text-align: center !important;
  font-size: 1.2em;
  margin-top: -20px;
}

/* Formulario */

.wpcf7-form h2 {
  text-align: center;
  margin-top: 60px !important;
  margin-bottom: 60px !important;
}

.domicilioempres {
  float: left;
  width: 70%;
}

.codigopostal {
  float: left;
  width: 30%;
  margin-bottom: 1.8%;
}

.Telefono {
  float: left;
  width: 70%;
}

.Fax {
  float: left;
  width: 30%;
  margin-bottom: 1.8%;
}

.provincia {
  float: left;
  width: 70%;
}

.Pais {
  float: left;
  width: 30%;
  margin-bottom: 1.8%;
}

.wpcf7-select {
  padding: 7px 10px !important;
}

.teamMembersContract {}

#pg-323-1 {
  margin-left: -15px;
  margin-right: -15px;
  position: relative;
  z-index: 120;
}

#menu-item-2471 {

  position: absolute;

  top: -1em;

  right: 1.2em;

  font-weight: 100;

  text-transform: none;

  color: #C7C3C3 !important;

}

@media (max-width: 767px) {

  #menu-item-2471 {

    top: -2.5em;

  }

}

#menu-item-2472 {
  position: absolute;
  top: -1em;
  right: 1.5em;
  text-transform: capitalize;
}

#menu-item-2472 a {

  color: #5B5B5B !important;

  padding-bottom: 0;

  padding-top: 5px;
}

#menu-item-2471 a {

  color: #C7C3C3 !important;

  padding-bottom: 0;

  padding-top: 5px;
}

#fondoPresupuesto {
  width: 100%;
}

.rev_slider>ul>li {

  cursor: pointer
}

.page-id-205 .tp-caption {
  margin: 0 auto !important;
}

.page-id-323 .more {
  background: #E21737;
  color: white;
  padding: .5em 1em;
  font-size: .8em;
  border-radius: .2em;
}

#pg-201-0 {
  margin: 8em 0 0 0;

}

#pg-201-2 {
  margin: 0 -15px !important;

}

.page-id-323 .more:after,
.blog-more:after {
  content: none
}

.gallery-item a:before {
  -webkit-backface-visibility: hidden;
  color: #222;
  content: none;
  font-family: "FontAwesome";
  font-size: 36px;
  left: 0;
  margin-top: -12px;
  text-align: center;
  top: 50%;
  transform: translateY(50px);
  width: 100%;
  z-index: 2;
  opacity: 0 !important;
}

.page-id-56 .portfolio.portfolio-masonry-spacing article:nth-child(3) {
  margin-top: 0%;
}

.anchorCountry {
  position: absolute;
  top: -14em;
}

#casosDestTitle {
  height: 1em;
  margin-bottom: 4.5em !important;
}

.blog-post-content p {

  font-family: 'Trebuchet MS' !important;
}

input[name="otrosRubros"] {

  margin: 2em 0;

}

.page-id-323 .nav-row,
.fixed-top-affix {

  z-index: 1000 !important;

}

.page-id-323 #panel-323-3-0-1 {

  padding-bottom: 9em !important;

}

.page-id-323 .site-footer {

  margin-top: 62px !important;

  padding-top: 0;

}

.botonBrochure a {
  background: #E21737;

  color: white;

  padding: .5em 1em;

  font-size: .8em;

  border-radius: .2em;
}

.rubro span.wpcf7-not-valid-tip {
  background-color: transparent !important;

  /* border: 1px solid #a4413e; */

  color: red;

  padding: 1em;

  position: absolute;

  width: 400px;

  top: -4em;
  box-sizing: border-box;

  border: none !important;
}

.site-header .nav-row {

  z-index: 2000 !important;
}

#gfxbucket_social-2 .fa-instagram:before {
  content: "\f16d";
  margin: 0 0 0 -1.3em !important;
}

#resulBusqueda {
  text-align: center;
  margin: 0 2em 2em 2em;
  text-transform: none !important;
  display: none;
}

#resulBusqueda .filtroSelected {
  color: #E21737;

}

#testimoniosDestacados {
  position: absolute;
  top: -10em;
}

.page-id-212 #panel-212-0-1-3 .social a {
  color: #EB566E !important;
}

.page-id-212 #panel-212-0-1-3 .social li {
  display: inline-block;
}

#gfxbucket_social-2 .social li:nth-child(5) a {
  margin: 0 0 0 1.1em !important;
}

body {

  font-size: 190% !important;

}

.destacadoAno {
  color: #E21737 !important;
  font-weight: bold !important;
  text-decoration: underline !important;
}

.page-id-209 .tp-bullets {
  left: 47.5% !important;
}

#pg-56-0 .parallax #rev_slider_3_1_wrapper {

  height: 400px !important;
}

#pg-56-0 .parallax {

  height: 400px !important;
}

@media screen and (max-width: 767px) {
  #pg-56-0 .parallax {
    height: 520px !important;
  }
}

#panel-56-1-1-0 blockquote {
  padding: 0;
  font-size: 1.5em !important;
}

.page-id-205 .tp-bgimg,
.forcefullwidth_wrapper_tp_banner,
.slider-team-top {
  /*height: 500px !important;*/
}

.page-id-392 #pgc-392-0-2,
#map {
  height: 659px;
}

@media (min-width: 1450px) {

  .page-id-392 #pgc-392-0-2,
  #map {
    height: 759px !important;
  }
}

#panel-392-0-1-3 {
  margin: 2em 1em 0 0;
  padding: 1em 0 0 0;
  border-top: 1px solid grey;
}

#pgc-392-1-1 {
  width: 40%;
  margin: 0 0 0 30%;
}

@media (min-width: 1050px) {
  #panel-205-1-0-1 p {
    font-size: 1em;

  }
}

@media (min-width: 1700px) {
  #pgc-205-1-0 {
    width: 60% !important;

  }

  #pgc-205-1-1 {
    width: 40% !important;
  }

}

#pg-323-0 {
  z-index: 1200;
  position: relative;
}

#pgc-356-1-0 blockquote {
  font-size: 1em !important;

}


@media (min-width: 500px) {

  #pgc-356-1-0 blockquote {
    font-size: 1.4em !important;

  }
}



.page-id-502 .filtros {
  font-size: 1em !important;
  margin-bottom: 2em;
}

.page-id-502 .filtros p {
  font-size: 1em !important;
}


#evolucion,
#comparativa {


  text-decoration: underline;
}


@media (min-width: 780px) {

  #evolucion,
  #comparativa {
    float: right;
    text-align: right;
    text-decoration: underline;
  }
}

a.ch,
a.pe,
a.uy {
  display: none;
}

div.ch,
div.pe,
div.uy {
  display: none;
}

.page-id-392 #pg-392-0 .social li {
  display: inline-block;
  margin: 1em 10px;
}

.page-id-392 #panel-392-0-2-2 div {
  text-align: left;
}

/*
.sow-image-container{
 display: none ;
}*/

@media (max-width: 31.250em) {
  .rev_slider .tp-revslider-mainul li .tp-parallax-wrap .tp-loop-wrap .tp-mask-wrap .tp-caption {
    font-size: 1.5em !important;
    font-family: Open Sans !important;
  }
}


@media (min-width: 60.625em) {

  .blog-home .blog-posts {
    border: 1px solid #DADADA !important;
    width: 48%;
    float: left;
    margin: 1% 1% 1% 0;
    padding-bottom: 0 !important;
    overflow: hidden;
    height: 280px;
    box-sizing: border-box;
  }

  .blog-home .blog-posts .blog-post-image {
    position: absolute !important;
    width: 100%;
    z-index: 1;
    padding-left: 0;
    padding-right: 0;
    top: 0;
    height: 280px;
  }

  .blog-home .blog-posts .blog-post-image img {
    border: 0 !important;
    /* height: 300px; */
    width: 120%;
    height: 100%;
  }

  .blog-home .blog-posts .blog-post-content {
    z-index: 2;
    opacity: 1;
    position: relative;
    background: rgba(255, 255, 255, 1) none repeat scroll 0% 0%;
    float: right;
    padding-top: 80px;
    min-height: 280px;
  }

}


@media (min-width: 103.750em) {
  .blog-home .blog-posts .blog-post-image img {
    border: 0 !important;
    /* height: 300px; */
    width: 100%;
    height: 100%;
  }

  .blog-home .blog-posts {
    border: 1px solid #DADADA !important;
    width: 48%;
    float: left;
    margin: 1% 1% 1% 0;
    padding-bottom: 0 !important;
    overflow: hidden;
    height: 300px;
    box-sizing: border-box;
  }

  .blog-home .blog-posts .blog-post-image {
    position: absolute !important;
    width: 100%;
    z-index: 1;
    padding-left: 0;
    padding-right: 0;
    top: 0;
    height: 300px;
  }

  .blog-home .blog-posts .blog-post-image img {
    border: 0 !important;
    /* height: 300px; */
    width: 120%;
    height: 100%;
  }

  .blog-home .blog-posts .blog-post-content {
    z-index: 2;
    opacity: 1;
    position: relative;
    background: rgba(255, 255, 255, 1) none repeat scroll 0% 0%;
    float: right;
    padding-top: 80px;
    min-height: 300px;
  }

}

#paginadorWp a {
  display: inline-block;
}

.page-id-392 #pl-392 .sow-image-container {
  display: none;

}

.rev_slider_wrapper .tp-mask-wrap .tp-caption {}

.tp-parallax-wrap,
.slotholder {}


.page-id-323 .site {
  padding-top: 50px !important;
}


@media (min-width: 1024px) {
.page-id-323 .site {
  padding-top:75px !important;
}
}

.page-id-323 .filtrosWp .filter {

  padding-bottom: .6em;
}

/* Pagination */
.paginationStash {
  clear: both;
  position: relative;
  font-size: 10px;
  /* Pagination text size */
  line-height: 13px;
  margin-left: auto;
  margin-right: auto;
  width: 400px;
  padding-top: 15px;
}

.pagination span,
.pagination li a {
  display: block;
  float: left;
  margin: 2px 2px 2px 0;
  padding: 8px 8px 8px 8px;
  text-decoration: none;
  width: auto;
  color: #fff;
  /* Pagination text color */
  background: #555;
  /* Pagination non-active background color */
  -webkit-transition: background .15s ease-in-out;
  -moz-transition: background .15s ease-in-out;
  -ms-transition: background .15s ease-in-out;
  -o-transition: background .15s ease-in-out;
  transition: background .15s ease-in-out;
  -webkit-border-radius: 30px;
  -moz-border-radius: 30px;
  border-radius: 25px;
}

.pagination li a:hover {
  color: #fff;
  background: #e21737;
  /* Pagination background on hover */
}

.pagination .current {
  padding: 8px 8px 8px 8px;
  background: #e21737;
  /* Current page background */
  color: #fff;
}

.paginadorsolo {

  clear: both !important;
  display: block !important;



}

.col_titulo {

  width: 35% !important;
}

.col_actividad {

  width: 35% !important;
}

.col_pais {

  width: 15% !important;
}

.col_ano {

  width: 10% !important;
}

#loading {
  display: none;
}


/* Absolute Center Spinner */
.loading {
  position: fixed;
  z-index: 999;
  height: 2em;
  width: 2em;
  overflow: auto;
  margin: auto;
  top: 0;
  left: 0;
  bottom: 0;
  right: 0;
}

/* Transparent Overlay */
.loading:before {
  content: '';
  display: block;
  position: fixed;
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
  background-color: rgba(0, 0, 0, 0.3);
}

/* :not(:required) hides these rules from IE9 and below */
.loading:not(:required) {
  /* hide "loading..." text */
  font: 0/0 a;
  color: transparent;
  text-shadow: none;
  background-color: transparent;
  border: 0;
}

.loading:not(:required):after {
  content: '';
  display: block;
  font-size: 10px;
  width: 1em;
  height: 1em;
  margin-top: -0.5em;
  -webkit-animation: spinner 1500ms infinite linear;
  -moz-animation: spinner 1500ms infinite linear;
  -ms-animation: spinner 1500ms infinite linear;
  -o-animation: spinner 1500ms infinite linear;
  animation: spinner 1500ms infinite linear;
  border-radius: 0.5em;
  -webkit-box-shadow: rgba(0, 0, 0, 0.75) 1.5em 0 0 0, rgba(0, 0, 0, 0.75) 1.1em 1.1em 0 0, rgba(0, 0, 0, 0.75) 0 1.5em 0 0, rgba(0, 0, 0, 0.75) -1.1em 1.1em 0 0, rgba(0, 0, 0, 0.5) -1.5em 0 0 0, rgba(0, 0, 0, 0.5) -1.1em -1.1em 0 0, rgba(0, 0, 0, 0.75) 0 -1.5em 0 0, rgba(0, 0, 0, 0.75) 1.1em -1.1em 0 0;
  box-shadow: rgba(0, 0, 0, 0.75) 1.5em 0 0 0, rgba(0, 0, 0, 0.75) 1.1em 1.1em 0 0, rgba(0, 0, 0, 0.75) 0 1.5em 0 0, rgba(0, 0, 0, 0.75) -1.1em 1.1em 0 0, rgba(0, 0, 0, 0.75) -1.5em 0 0 0, rgba(0, 0, 0, 0.75) -1.1em -1.1em 0 0, rgba(0, 0, 0, 0.75) 0 -1.5em 0 0, rgba(0, 0, 0, 0.75) 1.1em -1.1em 0 0;
}

/* Animation */

@-webkit-keyframes spinner {
  0% {
    -webkit-transform: rotate(0deg);
    -moz-transform: rotate(0deg);
    -ms-transform: rotate(0deg);
    -o-transform: rotate(0deg);
    transform: rotate(0deg);
  }

  100% {
    -webkit-transform: rotate(360deg);
    -moz-transform: rotate(360deg);
    -ms-transform: rotate(360deg);
    -o-transform: rotate(360deg);
    transform: rotate(360deg);
  }
}

@-moz-keyframes spinner {
  0% {
    -webkit-transform: rotate(0deg);
    -moz-transform: rotate(0deg);
    -ms-transform: rotate(0deg);
    -o-transform: rotate(0deg);
    transform: rotate(0deg);
  }

  100% {
    -webkit-transform: rotate(360deg);
    -moz-transform: rotate(360deg);
    -ms-transform: rotate(360deg);
    -o-transform: rotate(360deg);
    transform: rotate(360deg);
  }
}

@-o-keyframes spinner {
  0% {
    -webkit-transform: rotate(0deg);
    -moz-transform: rotate(0deg);
    -ms-transform: rotate(0deg);
    -o-transform: rotate(0deg);
    transform: rotate(0deg);
  }

  100% {
    -webkit-transform: rotate(360deg);
    -moz-transform: rotate(360deg);
    -ms-transform: rotate(360deg);
    -o-transform: rotate(360deg);
    transform: rotate(360deg);
  }
}

@keyframes spinner {
  0% {
    -webkit-transform: rotate(0deg);
    -moz-transform: rotate(0deg);
    -ms-transform: rotate(0deg);
    -o-transform: rotate(0deg);
    transform: rotate(0deg);
  }

  100% {
    -webkit-transform: rotate(360deg);
    -moz-transform: rotate(360deg);
    -ms-transform: rotate(360deg);
    -o-transform: rotate(360deg);
    transform: rotate(360deg);
  }
}


/* 20170518 EDIT */

.blog-post-meta {
  border-top: 1px solid #e1e1e1 !important;
  border-bottom: none !important
}

.share+.blog-post-categories {
  margin-top: 0 !important
}

.blog-post-categories {
  text-align: left;
}

.single-post .site-main {
  margin-bottom: 0px;
}

#pgc-6451-1-1 {
  z-index: 999;
  position: relative;
}

.portfolio {
  z-index: 99;
}

body .panel-widget-style-home .sow-features-list .sow-features-feature .sow-icon-container .sow-icon-fontawesome {
  margin: 0 0 0 -2px !important;
}

body.single-post div.recent-posts article {
  display: none;
}

body.home .blog-home .blog-posts footer.masnews {
  position: absolute !important;
  bottom: 0 !important;
  right: 0 !important;
  left: 50% !important;
  width: 50%;
  text-align: right !important;
  padding: 0 !important;
  margin: 0 0 0 0px !important;
}


.portfolio.portfolio-masonry-spacing article {
  overflow: hidden;
}



@media (min-width: 800px) {

  .blog-home .blog-posts a.more {
    padding: 4px 5px 5px 5px;
    background: white;
    max-width: 80px;
    border-radius: 3px;
    border: 1px solid #CCC !important;
    margin: 5px 0 0 0;
    right: 0;
  }

  .blog-home .blog-posts footer {
    left: 0;
  }

  .styled-select4 select {
    width: 258px !important;
  }

  .anossWp a:first-child,
  .anossWp a:nth-child(2),
  .anossWp a:nth-child(3),
  .anossWp a:nth-child(4),
  .anossWp a:nth-child(5),
  .anossWp a:nth-child(6),
  .anossWp a:nth-child(7),
  .anossWp a:nth-child(8),
  .anossWp a:nth-child(9) {
    display: none !important;
  }

  footer.site-footer {
    padding: 0px 0 0;
  }

  footer.site-footer .copyright {
    font-size: 12px !important;
  }

  div.footer-content {
    padding-bottom: 30px !important;
  }



  /* 20170531 */
  body.page-id-9186 footer.site-footer {
    padding: 0 !important;
  }

  .wpcf7-submit {
    float: right;
    margin: -60px 0 0 0 !important;
    min-width: 100px;
    z-index: 999;
    position: absolute;
    right: 0;
  }

  .wpcf7-form {
    margin-bottom: 80px;
    position: relative;
  }

  /* 20170628 */
  .blog-masonry .blog-post-image {
    max-height: 240px;
  }

  .blog-interior .blog-posts a.blog-post-comments-link {
    display: none;
  }

  .blog-interior .blog-posts .blog-post-image img {
    left: 0 !important;
    width: auto;
    max-height: 360px !important;
    top: -50px;
  }

  .blog-masonry .blog-post-title {
    font-size: 21px;
    line-height: 1.3;
    letter-spacing: 0.0em;
  }

  .blog-masonry .blog-post-content {
    max-height: 322px;
    overflow: hidden;
  }

  .blog-masonry .blog-posts {
    height: 600px;
    overflow: hidden;
  }

  .blog-posts footer {
    position: absolute !important;
    background: white;
    bottom: 0;
    width: 100%;
    height: 50px;
  }

  div#slide-53-layer-4.tp-caption.rev-btn.rs-parallaxlevel-0.noSwipe.rs-hover-ready {
    cursor: pointer !important;
  }

}






@media (max-width: 1024px) {
  .wpcf7-submit {
    float: none;
    margin: 10px 0 80px 0 !important;
    right: auto;
    width: 100%;
  }

  footer #gfxbucket_social-2 {
    margin-top: -515px;
  }

  footer .widget-title {
    margin-bottom: -10px;
  }

  footer #gfxbucket-visual-editor-2 {
    margin-top: -420px;
  }

  footer .wpcf7-form input.wpcf7-validates-as-required {
    width: 98%;
  }

  .site-footer .copyright {
    line-height: 1.4 !important;
    padding: 20px 10px !important;
  }

}


@media (max-width: 768px) {

  body.home .rev_slider .tp-revslider-mainul li .tp-parallax-wrap .tp-loop-wrap .tp-mask-wrap .tp-caption {
    font-size: 1.5em !important
  }

  body.home .slider-home-top .tp-parallax-wrap .tp-caption.BigBold-SubTitle {
    top: -1px !important;
  }

  #panel-56-1-1-0 blockquote {
    font-size: 1.2em !important;
  }

  body.home #rev_slider_6_2.rev_slider .tp-revslider-mainul li .tp-parallax-wrap .tp-loop-wrap .tp-mask-wrap .tp-caption {
    text-align: center;
    line-height: 1 !important;
  }

  body.home .blog-home .blog-posts a {
    float: none;
    width: 100%;
  }

  body.home .blog-home .blog-posts a,
  .blog-home .blog-posts .blog-post-content,
  .blog-home .blog-posts footer {
    width: 100%;
  }

  body.home .blog-home .blog-posts .blog-post-title {
    margin-top: 10px !important;
  }

  body.home .blog-home .blog-posts footer {
    position: relative !important;
    bottom: 0;
    left: 0 !important;
  }

  body.home .blog-home .blog-posts a.more::after {
    display: none;
  }

  body.home .blog-post-content {
    display: inline-block !important;
    min-height: 50px !important;
    text-align: left !important;
  }

  .blog-home .blog-posts a.more {
    right: 0;
    text-align: center;
  }

  .video-interna:first-child {
    padding-top: 70px !important;
    margin-bottom: 0px !important;
  }

  .arg .panel-grid-cell:first-child {
    width: 100% !important;
    float: left !important;
  }

  body.page-id-323 .filter {
    min-height: 180px !important;
  }

  body.page-id-323 .styled-select select {
    width: 100% !important;
  }

  body.page-id-323 .styled-select4 {
    width: 100% !important;
  }

  #FiltroButton,
  #FiltroButton2 {
    line-height: 1;
    margin: 0 3px 0 0;
  }
}




@media (max-width: 484px) {
  body.home .blog-home .blog-posts a {
    float: none;
    width: 100%;
  }

  body.home .blog-home .blog-posts a,
  .blog-home .blog-posts .blog-post-content,
  .blog-home .blog-posts footer {
    width: 100%;
  }

  body.home .blog-home .blog-posts .blog-post-title {
    margin-top: 10px !important;
  }

  body.home .blog-home .blog-posts footer {
    position: relative !important;
    bottom: 0;
    left: 0 !important;
  }

  .blog-home .blog-posts a.more {
    right: 0;
    text-align: center;
  }

  .video-interna:first-child {
    padding-top: 70px !important;
    margin-bottom: 0px !important;
  }

  .arg .panel-grid-cell:first-child {
    width: 100% !important;
    float: left !important;
  }

  body.page-id-323 .filter {
    min-height: 180px !important;
    padding: .2em 1em !important;
  }

  body.page-id-323 .styled-select select {
    width: 100% !important;
  }

  body.page-id-323 .styled-select4 {
    width: 100% !important;
  }

  #FiltroButton,
  #FiltroButton2 {
    line-height: 1;
    margin: 0 3px 0 0;
  }
}

.linkidioma a {
  padding-bottom: 0 !important;
}

.paginadorsolo .pagination>li {
  display: none;
}

body.page-id-14897 .chart .panel-grid-cell-mobile-last h3.widget-title small::after,
body.page-id-12066 .chart .panel-grid-cell-mobile-last h3.widget-title small::after {
  display: block;
  font-size: 1em !important;
  content: '/ EXCELENTE';
  padding-top: 2px;
}






@media (min-width: 1600px) {
  .portfolio.portfolio-masonry-spacing article {
    max-height: 326px;
    margin-bottom: 3px;
  }
}

@media (max-width: 1500px) {
  .portfolio.portfolio-masonry-spacing article {
    max-height: 276px;
    margin-bottom: 3px;
  }
}


@media (max-width: 1400px) {
  .portfolio.portfolio-masonry-spacing article {
    max-height: 263px;
    margin-bottom: 3px;
  }
}

@media (max-width: 1366px) {
  .portfolio.portfolio-masonry-spacing article {
    max-height: 248px;
    margin-bottom: 3px;
  }
}

@media (max-width: 1280px) {
  .portfolio.portfolio-masonry-spacing article {
    max-height: 235px;
    margin-bottom: 3px;
  }
}

@media (max-width: 1024px) {
  .portfolio.portfolio-masonry-spacing article {
    max-height: 188px;
    margin-bottom: 3px;
  }
}

@media (max-width: 854px) {
  .portfolio.portfolio-masonry-spacing article {
    max-height: 148px;
    margin-bottom: 3px;
  }
}

@media (max-width: 768px) {
  .portfolio.portfolio-masonry-spacing article {
    max-height: 144px;
    margin-bottom: 3px;
  }
}

@media (max-width: 736px) {
  .portfolio.portfolio-masonry-spacing article {
    max-height: 254px;
    margin-bottom: 3px;
  }
}

@media (max-width: 667px) {
  .portfolio.portfolio-masonry-spacing article {
    max-height: 224px;
    margin-bottom: 3px;
  }
}

@media (max-width: 640px) {
  .portfolio.portfolio-masonry-spacing article {
    max-height: 214px;
    margin-bottom: 3px;
  }
}



.color.talk-home .contact-home .wpcf7-form p {
  color: #fff !important;
}

#pg-205-2,
#pg-56-7 {
  margin-bottom: 0px !important;
}

.site-header .nav-menu #menu-item-13635.current-menu-item>a,
.site-header .nav-menu #menu-item-9188.current-menu-item>a {
  color: #222 !important
}

#pg-323-0>.panel-row-style {
  background-color: #e21737;
  margin-bottom: 0px !important;
  margin-top: 0px !important;
}

#pg-323-0 {
  margin-bottom: 0 !important;
}

#pg-323-4>.panel-row-style {
  margin: 0px !important;
}

/* FIX 201811 HOME ICONS*/
.panel-widget-style-home .sow-features-list .sow-features-feature .sow-icon-container {
  top: 10%;
}


/* FIX 201811 PORTFOLIO GRID */
.portfolio.portfolio-masonry-spacing article.portfolio-large {
  width: 25% !important;
}

.gallery-item:nth-child(3),
.gallery-item:nth-child(5) {
  width: 25% !important;
}

figure.gallery-item:nth-child(3) {
  margin-top: 0;
}

@media (max-width: 767px) {
  .portfolio.portfolio-masonry-spacing article.portfolio-large {
    width: 50% !important;
  }

  .gallery-item:nth-child(3),
  .gallery-item:nth-child(5) {
    width: 50% !important;
  }
}

@media (max-width: 484px) {
  .portfolio.portfolio-masonry-spacing article.portfolio-large {
    width: 100% !important;
  }

  .gallery-item:nth-child(3),
  .gallery-item:nth-child(5) {
    width: 100% !important;
  }
}


/* FIX 201811 PORTFOLIO */
.portfolio.portfolio-masonry-spacing article {
  float: none;
  display: inline-block;
  display: inline-flex;
  margin-bottom: 0
}

.page-id-323 #panel-323-3-0-1 {
  padding-bottom: 0em !important;
}

#pg-323-3>.panel-row-style {
  margin-bottom: 0 !important;
}

/* FIX 201811 SERVICE */
.panel-widget-style-home .sow-features-list .sow-features-feature,
.panel-widget-style-home .sow-features-list .sow-features-feature p {
  color: #fff !important;
  font-weight: 300;
  font-family: 'Lato', sans-serif !important;
  font-size: 16px !important;
}

/* FIX 201902 SERVICE */
@media (min-width: 800px) {
  .blog-interior .blog-posts .blog-post-image img {
    left: 0 !important;
    width: auto;
    max-height: 360px !important;
    top: 0;
    margin: 0;
  }
}


/* RE #edit 20201013 */
/*
body.page-id-356 .blog-masonry .blog-post-content, 
body.page-id-2466 .blog-masonry .blog-post-content {
	   overflow-y: hidden !important;
}*/

/* #edit 20190228 */
.page-id-323 .site-footer {
  margin-top: 0 !important;
}

.site-footer .footer-content .widget:first-of-type {
  margin-top: 0 !important;
}

#pg-323-4>.panel-row-style {
  margin-top: -58px !important;
  margin-bottom: -58px !important;
}


@media (max-width: 767px) {
  .portfolio {
    width: 100% !important;
    top: -20px !important;
    margin-bottom: -150px !important;
    margin-left: 0px !important;
    margin-right: 0px !important;
  }

  .caja360 {
    margin: 0 0 0 0 !important;
  }
}

body.page-id-356 .blog-load-more {
  font-size: 0 !important;
}

.blog-load-more::after {
  display: inline-block;
  content: 'Ver más';
  font-size: 15px;
  left: 0;
}

body.page-id-356 .site-footer {
  margin-top: -60px !important;
}

.masNoticiasHomeButton .btn.btn-lg {
  transform: translateX(-50%) !important;
  left: 50% !important;
  position: absolute !important;
}

/*20190610*/
.so-widget-gfxbucket-video {
  margin-bottom: 15px !important;
}

.gallery-item:nth-child(8) {
  margin-top: 0 !important;
}

/*20190806*/

@media (min-width: 768px) {
  .gallery {
    display: flex;
    flex-wrap: wrap;
  }

  .gallery-item {
    float: none;
    position: relative;
  }

  .gallery-item a {
    display: block;
    position: absolute;
    top: 0;
    left: 0;
  }

  .gallery-columns-4 .gallery-item,
  .gallery-item:nth-child(3),
  .gallery-item:nth-child(5) {
    width: 33% !important;
    padding-bottom: 22%;
    overflow: hidden;
    margin-bottom: 5px;
  }
}

@media (min-width: 992px) {
  .gallery-item {
    float: none;
    position: relative;
  }

  .gallery-item a {
    display: block;
    position: absolute !important;
    top: 0;
    left: 0;
  }

  .gallery-columns-4 .gallery-item {
    width: 25% !important;
    padding-bottom: 16.0%;
    overflow: hidden;
    margin-bottom: 5px;
  }
}

.gallery-item a:after {
  bottom: 0;
  left: 0;
  right: 0;
  top: 0;
  background-color: rgba(255, 255, 255, .65);
}


/*20190925*/
body.tag #main div:first-child {
  display: none !important
}

.site-footer .widget-title {
  padding: 0
}

/*20191013*/
li#menu-item-6237>a,
li#menu-item-13635>a {
  color: #e21737 !important;
}

/*20200421*/
@media (max-width: 799px) {
  .blog-masonry .blog-post-content {
    display: none !important;
  }

  .blog-masonry .blog-post-image {
    border-style: none;
    overflow: hidden;
    position: relative;
    max-height: 250px;
    padding-top: 56.66%;
  }

  .blog-interior .blog-posts .blog-post-image img {
    border: 0 !important;
    left: 50% !important;
    width: 100%;
    height: auto;
    min-height: 180px;
    top: 0;
    margin: 0;
    transform: translate(-50%, 0);
    position: absolute;
  }
}

@media (min-width: 800px) {
  .blog-masonry .blog-post-image {
    max-height: 250px;
    padding-top: 56.66%;
  }

  .blog-interior .blog-posts .blog-post-image img {
    /* left: 50% !important; */
    width: auto;
    height: 100%;
    /* max-height: 250px !important;
    min-height: 190px !important; */
    top: 0;
    margin: 0;
    /* transform: translate(-50%,0); */
    position: absolute;
  }
}


/*20200608*/
@media (max-width: 767px) {

  .site .container .portfolio-post-header-meta li.superficier,
  .site .container .portfolio-post-header-meta li.plazo_de_la_obra {
    display: block !important;
    width: 100% !important;
  }

  .portfolio-post-header-heading {
    font-size: 32px !important;
  }

  .portfolio-post-header-heading-small {
    font-size: 22px !important;
  }

  .portfolio-post-header.no-background {
    height: 80px;
    margin-top: 0;
  }
}

@media (min-width: 992px) {
  .site-footer .widget {
    margin: 50px 0;
  }
}

@media (min-width: 1700px) {
  body.page-id-201 #pgc-205-1-0 {
    width: 100% !important;
  }
}

.chart h3.widget-title small {
  display: block;
  margin: 0 auto;
  max-width: 60%;
  max-width: 80px;
}

//20201029
.blog-masonry .blog-post-image img {
  margin-top: 0 !important;
  position: absolute !important;
  top: 50% !important;
  transform: translateY(-50%) !important;
}

@media (min-width: 768px) {
  .portfolio-post-header {
    background-position: center center !important;
  }
}

@media (max-width: 419px) {
  .portfolio-post-header-content .portfolio-post-header-heading {
    font-size: 1.75em !important;
  }
}


/* 2021-03-11 */
.blog-masonry .blog-post-image {
  max-height: 200px;
  min-height: 160px;
  display: block;
  outline: none;
  padding: 0;
  margin: 0;
}
.blog-interior .blog-posts .blog-post-image img {
  left: 50% !important;
  width: 110% !important;
  height: auto !important;
  top: 50% !important;
  margin: 0 !important;
  transform: translate(-50%,-50%)!important;
  position: absolute;
  display: block;
  outline: none;
}
//


.team .team-social {
    position: relative;
    z-index: 99;
}

.team .team-social:after {
	height:0;
}
.title-team .title {
    z-index: -1;
}

#rowsCasos td {  
    overflow: hidden;
    max-height: 40px;
    height: 40px;
}
#rowsCasos td.col_pais {
    min-width: 200px!important;
}



.page-id-209 #pg-209-0,#pg-209-1 {
	display:none;
}
.blog-posts a.more {  
    font-size: 13px;
}

@media (max-width: 1024px) {
	.blog-masonry footer {
	    width: fit-content;
	    margin: 0 0 0 20px;
	}
	.blog-posts a.more { 
	    color: #fff!important; 
	}
}
